import * as react from 'react';
import { ReactNode, SVGProps, ReactElement, MouseEvent, ReactEventHandler } from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { SortColumn } from 'react-data-grid';
import * as styled_components from 'styled-components';

type Space$1 = "xxsmall" | "xsmall" | "small" | "medium" | "large" | "xlarge" | "xxlarge";
type Margin = {
    top?: Space$1;
    bottom?: Space$1;
    left?: Space$1;
    right?: Space$1;
};
type SVG = ReactNode & SVGProps<SVGSVGElement>;

type AccordionItemProps = {
    /**
     * The panel label.
     */
    label: string;
    /**
     * Additional info label positioned under the label.
     */
    subLabel?: string;
    /**
     * Badge component to add extra value to the accordion.
     */
    badge?: {
        position: "before" | "after";
        element: ReactNode;
    };
    /**
     * Status light component to add extra value to the accordion.
     */
    statusLight?: ReactNode;
    /**
     * Material Symbol name or SVG element used as the icon that will be
     * placed next to panel label. When using Material Symbols, replace spaces with underscores.
     * By default they are outlined if you want it to be filled
     * prefix the symbol name with "filled_".
     */
    icon?: string | SVG;
    /**
     * Assistive text to be placed on the right side of the panel.
     */
    assistiveText?: string;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * The expanded panel of the accordion. This area can be used to render
     * custom content.
     */
    children: ReactNode;
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
};
type CommonProps$9 = {
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Contains one or more accordion items.
     */
    children: ReactElement<AccordionItemProps>[] | ReactElement<AccordionItemProps>;
};
type IndependentProps = CommonProps$9 & {
    /**
     * When true, limits the user to single-open section at a time. When false, multiple sections can be opened simultaneously.
     */
    independent: true;
    /**
     * Initially active accordion, only when it is uncontrolled.If the accordion is not independent,
     * several accordions can be activated by default.
     */
    defaultIndexActive?: number;
    /**
     * The index of the active accordion. If undefined, the component will be uncontrolled and the active
     * accordion will be managed internally by the component. If null, the component will be controlled and all
     * accordions will be closed. If the accordion is not independent, several accordions can be activated.
     */
    indexActive?: number;
    /**
     * This function will be called when the user clicks on an accordion. The index of the clicked accordion will be passed as a parameter.
     */
    onActiveChange?: (index: number) => void;
};
type NonIndependentProps = CommonProps$9 & {
    /**
     * When true, limits the user to single-open section at a time. When false, multiple sections can be opened simultaneously.
     */
    independent?: false;
    /**
     * Initially active accordion, only when it is uncontrolled. If the accordion is not independent,
     * several accordions can be activated by default.
     */
    defaultIndexActive?: number[];
    /**
     * The index of the active accordion. If undefined, the component will be uncontrolled and the active
     * accordion will be managed internally by the component. If null, the component will be controlled and all
     * accordions will be closed. If the accordion is not independent, several accordions can be activated.
     */
    indexActive?: number[];
    /**
     * This function will be called when the user clicks on an accordion. The index of the clicked accordion will be passed as a parameter.
     */
    onActiveChange?: (index: number[]) => void;
};
type Props$J = IndependentProps | NonIndependentProps;

declare const DxcAccordion: {
    (props: Props$J): JSX.Element;
    AccordionItem: ({ label, subLabel, badge, statusLight, icon, assistiveText, disabled, children, tabIndex, }: AccordionItemProps) => JSX.Element;
};

type Action$2 = {
    /**
     * The icon of the action. It can be a string with the name of the icon or an SVG component.
     */
    icon?: string | SVG;
    /**
     * The label of the action.
     */
    label: string;
    /**
     * The function that will be executed when the user clicks on the action button.
     */
    onClick: () => void;
};
type Message = {
    /**
     * The function that will be executed when the user clicks on the close action button.
     */
    onClose?: () => void;
    /**
     * The content of the message. The only Halstack component allowed within the text of an alert is the Link component,
     * and it should be used exclusively to direct users to additional resources or relevant pages.
     * No other components are permitted within the content of an alert.
     */
    text: ReactNode;
};
type CommonProps$8 = {
    /**
     * If true, the alert will have a close button that will remove the message from the alert,
     * only in banner and inline modes. The rest of the functionality will depend
     * on the onClose event of each message (e.g. closing the modal alert).
     */
    closable?: boolean;
    /**
     * Primary action of the alert.
     */
    primaryAction?: Action$2;
    /**
     * Secondary action of the alert.
     */
    secondaryAction?: Action$2;
    /**
     * Specifies the semantic meaning of the alert.
     */
    semantic?: "error" | "info" | "success" | "warning";
    /**
     * Title of the alert.
     */
    title: string;
};
type ModeSpecificProps = {
    /**
     * List of messages to be displayed. Each message has a close action that will,
     * apart from remove from the alert the current message, call the onClose if it is defined.
     * If the message is an array, the alert will show a navigation bar to move between the messages.
     * The modal mode only allows one message per alert. In this case, the message must be an object
     * and the presence of the onClose attribute is mandatory, since the management of the closing
     * of the alert relies completely on the user.
     */
    message?: Message | Message[];
    /**
     * The mode of the alert.
     */
    mode?: "inline" | "banner";
} | {
    /**
     * List of messages to be displayed. Each message has a close action that will,
     * apart from remove from the alert the current message, call the onClose if it is defined.
     * If the message is an array, the alert will show a navigation bar to move between the messages.
     * The modal mode only allows one message per alert. In this case, the message must be an object
     * and the presence of the onClose attribute is mandatory, since the management of the closing
     * of the alert relies completely on the user.
     */
    message: Required<Message>;
    /**
     * The mode of the alert.
     */
    mode: "modal";
};
type Props$I = CommonProps$8 & ModeSpecificProps;

declare function DxcAlert({ closable, message, mode, primaryAction, secondaryAction, semantic, title, }: Props$I): react_jsx_runtime.JSX.Element;

type SidenavTitlePropsType = {
    /**
     * The area inside the sidenav title. This area can be used to render custom content.
     */
    children: ReactNode;
};
type SidenavSectionPropsType = {
    /**
     * The area inside the sidenav section. This area can be used to render sidenav groups, links and custom content.
     */
    children: ReactNode;
};
type SidenavGroupPropsType = {
    /**
     * The title of the sidenav group.
     */
    title?: string;
    /**
     * If true, the sidenav group will be a button that will allow you to collapse the links contained within it.
     * In addition, if it's collapsed and contains the currently selected link, the group title will also be marked as selected.
     */
    collapsable?: boolean;
    /**
     * Material Symbol name or SVG icon to be displayed next to the title of the group.
     */
    icon?: string | SVG;
    /**
     * The area inside the sidenav group. This area can be used to render sidenav links.
     */
    children: ReactNode;
};
type SidenavLinkPropsType = {
    /**
     * Page to be opened when the user clicks on the link.
     */
    href?: string;
    /**
     * If true, the page is opened in a new browser tab.
     */
    newWindow?: boolean;
    /**
     * The Material symbol or SVG element used as the icon that will be placed to the left of the link text.
     */
    icon?: string | SVG;
    /**
     * If true, the link will be marked as selected. Moreover, in that same case,
     * if it is contained within a collapsed group, and consequently, the currently selected link is not visible,
     * the group title will appear as selected too.
     */
    selected?: boolean;
    /**
     * This function will be called when the user clicks the link and the event will be passed to this function.
     */
    onClick?: (event: MouseEvent<HTMLAnchorElement>) => void;
    /**
     * The area inside the sidenav link.
     */
    children: ReactNode;
    /**
     * Value of the tabindex.
     */
    tabIndex?: number;
};
type Props$H = {
    /**
     * The area assigned to render the sidenav title. It is highly recommended to use the sidenav title.
     */
    title?: ReactNode;
    /**
     * The area inside the sidenav. This area can be used to render the content inside the sidenav.
     */
    children: ReactNode;
};

type Size$4 = "small" | "medium" | "large" | "fillParent" | "fitContent";
type Option$1 = {
    /**
     * Option display value.
     */
    label?: string;
    /**
     * Material Symbol name or SVG element as the icon that will be placed next to the label.
     */
    icon?: string | SVG;
    /**
     * Option inner value.
     */
    value: string;
};
type Props$G = {
    /**
     * An array of objects representing the options.
     */
    options: Option$1[];
    /**
     * In case options include icons, whether the icon should appear
     * after or before the label.
     */
    optionsIconPosition?: "before" | "after";
    /**
     * Material Symbol name or SVG element as the icon that will be placed next to the label.
     */
    icon?: string | SVG;
    /**
     * Whether the icon should appear after or before the label.
     */
    iconPosition?: "before" | "after";
    /**
     * Text to be placed within the dropdown.
     */
    label?: string;
    /**
     * Whether the arrow next to the label must be displayed or not.
     */
    caretHidden?: boolean;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * If true, the options are shown when the dropdown is hover.
     */
    expandOnHover?: boolean;
    /**
     * This function will be called every time the selection changes.
     * The value of the selected option will be passed as a parameter.
     */
    onSelectOption: (value: string) => void;
    /**
     * Size of the margin to be applied to the component.
     * You can pass an object with 'top', 'bottom', 'left' and 'right'
     * properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: Size$4;
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
    /**
     * Text representing advisory information related to the dropdown's trigger action.
     * Under the hood, this prop also serves as an accessible label for the component.
     */
    title?: string;
};

type Props$F = {
    /**
     * Whether a contrast line should appear at the bottom of the header.
     */
    underlined?: boolean;
    /**
     * Content shown in the header. Take into account that the component applies styles
     * for the first child in the content, so we recommend the use of React.Fragment
     * to be applied correctly. Otherwise, the styles can be modified.
     */
    content?: ReactNode;
    /**
     * Content shown in responsive version. It receives the close menu handler that can
     * be used to add that functionality when a element is clicked.
     */
    responsiveContent?: (closeHandler: () => void) => ReactNode;
    /**
     * This function will be called when the user clicks the header logo.
     */
    onClick?: () => void;
    /**
     * Size of the bottom margin to be applied to the header.
     */
    margin?: Space$1;
    /**
     * Value of the tabindex for all interactive elements, except those inside the
     * custom area.
     */
    tabIndex?: number;
};

type SocialLink = {
    /**
     * URL of the page the link goes to.
     */
    href: string;
    /**
     * Material Symbol name or SVG element as the icon used for the link.
     */
    logo: string | SVG;
    /**
     * Value for the HTML properties title and aria-label.
     */
    title: string;
};
type BottomLink = {
    /**
     * URL of the page the link goes to.
     */
    href: string;
    /**
     * Text for the link.
     */
    text: string;
};
type FooterPropsType = {
    /**
     * An array of objects representing the links that will be rendered as
     * icons at the top-right side of the footer.
     */
    socialLinks?: SocialLink[];
    /**
     * An array of objects representing the links that will be rendered at
     * the bottom part of the footer.
     */
    bottomLinks?: BottomLink[];
    /**
     * The text that will be displayed as copyright disclaimer.
     */
    copyright?: string;
    /**
     * The center section of the footer. Can be used to render custom
     * content in this area.
     */
    children?: ReactNode;
    /**
     * Size of the top margin to be applied to the footer.
     */
    margin?: Space$1;
    /**
     * Value of the tabindex for all interactive elements, except those
     * inside the custom area.
     */
    tabIndex?: number;
    /**
     * Determines the visual style and layout
     * - "default": The default mode with full content and styling.
     * - "reduced": A reduced mode with minimal content and styling.
     */
    mode?: "default" | "reduced";
};

type AppLayoutMainPropsType = {
    /**
     * Everything between the tags will be displayed as the content of the main part of the application.
     */
    children: ReactNode;
};
type ApplicationLayoutPropsType = {
    /**
     * Text to be placed next to the hamburger button that toggles the
     * visibility of the sidenav.
     */
    visibilityToggleLabel?: string;
    /**
     * Header content.
     */
    header?: ReactNode;
    /**
     * Sidenav content
     */
    sidenav?: ReactNode;
    /**
     * Footer content
     */
    footer?: ReactNode;
    /**
     * Use the DxcApplicationLayout.Main provided to render main content.
     */
    children: ReactElement<AppLayoutMainPropsType>;
};

declare const DxcApplicationLayout: {
    ({ visibilityToggleLabel, header, sidenav, footer, children, }: ApplicationLayoutPropsType): JSX.Element;
    Footer: ({ socialLinks, bottomLinks, copyright, children, margin, tabIndex, mode, }: FooterPropsType) => JSX.Element;
    Header: {
        ({ underlined, content, responsiveContent, onClick, margin, tabIndex, }: Props$F): JSX.Element;
        Dropdown: (props: react.ComponentProps<({ options, optionsIconPosition, icon, iconPosition, label, caretHidden, disabled, expandOnHover, onSelectOption, margin, size, tabIndex, title, }: Props$G) => JSX.Element>) => react_jsx_runtime.JSX.Element;
    };
    Main: ({ children }: AppLayoutMainPropsType) => JSX.Element;
    SideNav: {
        ({ title, children }: Props$H): JSX.Element;
        Section: ({ children }: SidenavSectionPropsType) => JSX.Element;
        Group: ({ title, collapsable, icon, children }: SidenavGroupPropsType) => JSX.Element;
        Link: react.ForwardRefExoticComponent<SidenavLinkPropsType & react.RefAttributes<HTMLAnchorElement>>;
        Title: ({ children }: SidenavTitlePropsType) => JSX.Element;
    };
    useResponsiveSidenavVisibility: () => ((_isSidenavVisible: boolean) => void) | null;
};

type ContextualProps = {
    /**
     * Text to be placed in the badge.
     */
    label: string;
    /**
     * The available badge modes.
     */
    mode?: "contextual";
    /**
     * In notification mode, if the number entered as label is greater that this notification limit, +99 will be shown. If not, the entered text will be shown as label.
     */
    notificationLimit?: never;
    /**
     * Affects the visual style of the badge. It can be used following semantic purposes or not.
     */
    color?: "grey" | "blue" | "green" | "orange" | "red" | "yellow" | "purple";
};
type NotificationProps = {
    /**
     * Text to be placed in the badge.
     */
    label?: number;
    /**
     * The available badge modes.
     */
    mode: "notification";
    /**
     * In notification mode, if the number entered as label is greater that this notification limit, +99 will be shown. If not, the entered text will be shown as label.
     */
    notificationLimit?: number;
    /**
     * Affects the visual style of the badge. It can be used following semantic purposes or not.
     */
    color?: never;
};
type CommonProps$7 = {
    /**
     * Text representing advisory information related to the badge. Under the hood, this prop also serves as an accessible label for the component.
     */
    title?: string;
    /**
     *  Material Symbol name or SVG element used as the icon that will be placed next to the badge label in contextual mode.
     */
    icon?: string | SVG;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large";
};
type Props$E = (ContextualProps | NotificationProps) & CommonProps$7;

declare const DxcBadge: ({ label, title, mode, color, icon, notificationLimit, size, }: Props$E) => JSX.Element;

/**
 * Halstack Color Palette
 * @link https://developer.dxc.com/halstack/next/principles/color/#color-tokens-core-color-tokens
 */
declare const CoreColorTokens: {
    color_black: string;
    color_white: string;
    color_transparent: string;
    color_grey_50: string;
    color_grey_100: string;
    color_grey_200: string;
    color_grey_300: string;
    color_grey_400: string;
    color_grey_500: string;
    color_grey_600: string;
    color_grey_700: string;
    color_grey_800: string;
    color_grey_900: string;
    color_grey_50_a: string;
    color_grey_100_a: string;
    color_grey_200_a: string;
    color_grey_300_a: string;
    color_grey_400_a: string;
    color_grey_500_a: string;
    color_grey_600_a: string;
    color_grey_700_a: string;
    color_grey_800_a: string;
    color_grey_900_a: string;
    color_purple_50: string;
    color_purple_100: string;
    color_purple_200: string;
    color_purple_300: string;
    color_purple_400: string;
    color_purple_500: string;
    color_purple_600: string;
    color_purple_700: string;
    color_purple_800: string;
    color_purple_900: string;
    color_blue_50: string;
    color_blue_100: string;
    color_blue_200: string;
    color_blue_300: string;
    color_blue_400: string;
    color_blue_500: string;
    color_blue_600: string;
    color_blue_700: string;
    color_blue_800: string;
    color_blue_900: string;
    color_red_50: string;
    color_red_100: string;
    color_red_200: string;
    color_red_300: string;
    color_red_400: string;
    color_red_500: string;
    color_red_600: string;
    color_red_700: string;
    color_red_800: string;
    color_red_900: string;
    color_green_50: string;
    color_green_100: string;
    color_green_200: string;
    color_green_300: string;
    color_green_400: string;
    color_green_500: string;
    color_green_600: string;
    color_green_700: string;
    color_green_800: string;
    color_green_900: string;
    color_yellow_50: string;
    color_yellow_100: string;
    color_yellow_200: string;
    color_yellow_300: string;
    color_yellow_400: string;
    color_yellow_500: string;
    color_yellow_600: string;
    color_yellow_700: string;
    color_yellow_800: string;
    color_yellow_900: string;
    color_orange_50: string;
    color_orange_100: string;
    color_orange_200: string;
    color_orange_300: string;
    color_orange_400: string;
    color_orange_500: string;
    color_orange_600: string;
    color_orange_700: string;
    color_orange_800: string;
    color_orange_900: string;
};
type CoreColorTokensType = keyof typeof CoreColorTokens;
type CoreSpacingTokensType = "0rem" | "0.125rem" | "0.25rem" | "0.5rem" | "0.75rem" | "1rem" | "1.5rem" | "2rem" | "2.5rem" | "3rem" | "3.5rem" | "4rem" | "5rem" | "6rem" | "7rem";

type Props$D = {
    /**
     * Applies the spacing scale to all sides.
     */
    space?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the left and right sides.
     */
    horizontal?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the top and bottom sides.
     */
    vertical?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the top side.
     */
    top?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the right side.
     */
    right?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the bottom side.
     */
    bottom?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the left side.
     */
    left?: CoreSpacingTokensType;
    /**
     * Custom content inside the bleed.
     */
    children: ReactNode;
};

declare const Bleed: ({ space, horizontal, vertical, top, right, bottom, left, children }: Props$D) => react_jsx_runtime.JSX.Element;

type Item$1 = {
    href?: string;
    label: string;
};
type Props$C = {
    /**
     * Provides a label that describes the type of navigation enabled by
     * the component.
     */
    ariaLabel?: string;
    /**
     * Array of objects representing the items of the breadcrumbs.
     */
    items: Item$1[];
    /**
     * Number of items before showing a collapsed version of the
     * breadcrumbs. It can't be lower than two (root/collapsed action and
     * current page).
     */
    itemsBeforeCollapse?: number;
    /**
     * Callback for custom navigation with third-party libraries such as
     * Next ('useRouter') or React Router ('useNavigate').
     * This function will be called when an item is clicked,
     * receiving its 'href' as a parameter.
     * @param href
     * @returns
     */
    onItemClick?: (href: string) => void;
    /**
     * When items are collapsed, whether the root item should always be
     * displayed or not.
     */
    showRoot?: boolean;
};

declare const DxcBreadcrumbs: ({ ariaLabel, items, itemsBeforeCollapse, onItemClick, showRoot, }: Props$C) => react_jsx_runtime.JSX.Element;

type IconProps = {
    /**
     * Defines the style of the bullet point in the list.
     */
    type: "icon";
    /**
     * Icon to display as bullet.
     */
    icon: string | SVG;
    /**
     * Text to be shown in the list.
     */
    children: ReactNode;
};
type OtherProps = {
    /**
     * Defines the style of the bullet point in the list.
     */
    type?: "disc" | "circle" | "square" | "number";
    /**
     * Icon to display as bullet.
     */
    icon?: never;
    /**
     * Text to be shown in the list.
     */
    children: ReactNode;
};
type Props$B = IconProps | OtherProps;

type BulletedListItemPropsType = {
    /**
     * Text to be shown in the list.
     */
    children?: ReactNode;
};

declare const DxcBulletedList: {
    ({ children, type, icon }: Props$B): JSX.Element;
    Item: ({ children }: BulletedListItemPropsType) => JSX.Element;
};

type Size$3 = {
    /**
     * Height of the component.
     */
    height?: "small" | "medium" | "large";
    width?: "small" | "medium" | "large" | "fillParent" | "fitContent";
};
type Props$A = {
    /**
     * Text to be placed in the button.
     */
    label?: string;
    /**
     * The available button modes.
     */
    mode?: "primary" | "secondary" | "tertiary";
    /**
     * Specifies the semantic meaning of the buttons, which determines its color.
     */
    semantic?: "default" | "error" | "warning" | "success" | "info";
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * Whether the icon should appear after or before the label.
     */
    iconPosition?: "before" | "after";
    /**
     * Value for the HTML properties title and aria-label.
     */
    title?: string;
    /**
     * 'type' html prop of the button.
     */
    type?: "button" | "reset" | "submit";
    /**
     * Material Symbol name or SVG element as the icon that will be placed next to the label.
     */
    icon?: string | SVG;
    /**
     * This function will be called when the user clicks the button.
     */
    onClick?: () => void;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: Size$3;
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
};

declare const DxcButton: ({ label, mode, semantic, disabled, iconPosition, title, type, icon, onClick, margin, size, tabIndex, }: Props$A) => JSX.Element;

type Size$2 = {
    top?: Space$1;
    bottom?: Space$1;
    left?: Space$1;
    right?: Space$1;
};
type Props$z = {
    /**
     * URL of the image that will be placed in the card component.
     * In case of omission, the image container will not appear and
     * the content will occupy its space.
     */
    imageSrc?: string;
    /**
     * Color of the image background.
     */
    imageBgColor?: string;
    /**
     * Size of the padding to be applied to the image section of the
     * component. You can pass an object with 'top', 'bottom', 'left'
     * and 'right' properties in order to specify different padding sizes.
     */
    imagePadding?: Space$1 | Size$2;
    /**
     * Whether the image should appear in relation to the content.
     */
    imagePosition?: "before" | "after";
    /**
     * If defined, the tag will be displayed as an anchor, using this prop
     * as "href". Component will show some visual feedback on hover.
     */
    linkHref?: string;
    /**
     * This function will be called when the user clicks the card. Component
     * will show some visual feedback on hover.
     */
    onClick?: () => void;
    /**
     * Whether the image must cover the whole image area of the card.
     */
    imageCover?: boolean;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Size$2;
    /**
     * Value of the tabindex attribute applied when the component is clickable.
     */
    tabIndex?: number;
    /**
     * Determines whether or not the component should have an outline.
     */
    outlined?: boolean;
    /**
     * Custom content that will be placed inside the component.
     */
    children?: ReactNode;
};

declare const DxcCard: ({ imageSrc, imageBgColor, imagePadding, imagePosition, linkHref, onClick, imageCover, margin, tabIndex, outlined, children, }: Props$z) => JSX.Element;

type Props$y = {
    /**
     * Initial state of the checkbox, only when it is uncontrolled.
     */
    defaultChecked?: boolean;
    /**
     * If true, the component is checked. If undefined the component will be
     * uncontrolled and the value will be managed internally by the component.
     */
    checked?: boolean;
    /**
     * Will be passed to the value attribute of the html input element.
     * When inside a form, this value will be only submitted if the checkbox is checked.
     */
    value?: string;
    /**
     * Text to be placed next to the checkbox.
     */
    label?: string;
    /**
     * Whether the label should appear after or before the checkbox.
     */
    labelPosition?: "before" | "after";
    /**
     * Name attribute of the input element.
     */
    name?: string;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * If true, the component will display '(Optional)' next to the label.
     */
    optional?: boolean;
    /**
     * If true, the component will not be mutable, meaning the user can not edit the control.
     */
    readOnly?: boolean;
    /**
     * This function will be called when the user clicks the checkbox.
     * The new value will be passed as a parameter.
     */
    onChange?: (value: boolean) => void;
    /**
     * Size of the margin to be applied to the component
     * ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties
     * in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent" | "fitContent";
    /**
     * Value of the tabindex.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the checkbox element when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcCheckbox: react.ForwardRefExoticComponent<Props$y & react.RefAttributes<HTMLDivElement>>;

type Props$x = {
    /**
     * Text to be placed on the chip.
     */
    label?: string;
    /**
     * Element or path used as icon to be placed after the chip label.
     */
    suffixIcon?: string | SVG;
    /**
     * Element or path used as icon to be placed before the chip label.
     */
    prefixIcon?: string | SVG;
    /**
     * This function will be called when the suffix is clicked.
     */
    onClickSuffix?: () => void;
    /**
     * This function will be called when the prefix is clicked.
     */
    onClickPrefix?: () => void;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
};

declare const DxcChip: ({ label, suffixIcon, prefixIcon, onClickSuffix, onClickPrefix, disabled, margin, tabIndex, }: Props$x) => JSX.Element;

type Space = Space$1 | {
    top?: Space$1;
    right?: Space$1;
    bottom?: Space$1;
    left?: Space$1;
};
type Inset$1 = {
    top?: string;
    right?: string;
    bottom?: string;
    left?: string;
};
type Background = {
    attachment?: string;
    clip?: string;
    color?: CoreColorTokensType;
    image?: string;
    origin?: string;
    position?: string;
    repeat?: string;
    size?: string;
};
type BorderProperties = {
    width?: string;
    style?: "none" | "dotted" | "dashed" | "solid" | "double" | "groove" | "ridge" | "inset" | "outset";
    color?: CoreColorTokensType;
};
type Border = BorderProperties | {
    top?: BorderProperties;
    right?: BorderProperties;
    bottom?: BorderProperties;
    left?: BorderProperties;
};
type Outline = BorderProperties & {
    offset?: string;
};
type OverflowValues = "visible" | "hidden" | "clip" | "scroll" | "auto";
type Overflow = OverflowValues | {
    x?: OverflowValues;
    y?: OverflowValues;
};
type Props$w = {
    /**
     * Based on the CSS property background allows configuring all properties related to the background of a container.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/background
     */
    background?: Background;
    /**
     * Based on the CSS property border allows configuring all properties related to the border of a container.
     */
    border?: Border;
    /**
     * Sets the border-radius CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/border-radius
     */
    borderRadius?: string;
    /**
     * Sets the box-shadow CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/box-shadow
     */
    boxShadow?: string;
    /**
     * Sets the box-sizing CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/box-sizing
     */
    boxSizing?: "border-box" | "content-box";
    /**
     * Custom content inside the container.
     */
    children: ReactNode;
    /**
     * Sets the display CSS property.
     * The set of values is limited to the ones related to the outer display type.
     * If you want to apply any pattern from the inner box and how the children are laid out,
     * we recommend you to use the Flex and Grid components.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/display
     */
    display?: "block" | "inline-block" | "inline" | "none";
    /**
     * Sets the float CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/float
     */
    float?: "left" | "right" | "none";
    /**
     * Sets the height CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/height
     */
    height?: string;
    /**
     * Based on the CSS property inset this prop is a shorthand that corresponds
     * to the top, right, bottom, and/or left properties.
     */
    inset?: Inset$1;
    /**
     * Size of the margin to be applied to the component.
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties
     * in order to specify different margin sizes.
     */
    margin?: Space;
    /**
     * Sets the max-height CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/max-height
     */
    maxWidth?: string;
    /**
     * Sets the max-width CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/max-width
     */
    maxHeight?: string;
    /**
     * Sets the min-height CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/min-height
     */
    minWidth?: string;
    /**
     * Sets the min-width CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/min-width
     */
    minHeight?: string;
    /**
     * Based on the CSS property outline allows configuring all properties related
     * to the outline of a container.
     */
    outline?: Outline;
    /**
     * Sets the overflow CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/overflow
     */
    overflow?: Overflow;
    /**
     * Size of the margin to be applied to the component.
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties
     * in order to specify different margin sizes.
     */
    padding?: Space;
    /**
     * Sets the position CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/position
     */
    position?: "static" | "relative" | "absolute" | "fixed" | "sticky";
    /**
     * Sets the width CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/width
     */
    width?: string;
    /**
     * Sets the z-index CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/z-index
     */
    zIndex?: "auto" | number;
};

declare function DxcContainer({ display, width, height, overflow, ...props }: Props$w): react_jsx_runtime.JSX.Element;

type CommonItemProps = {
    badge?: ReactElement;
    icon?: string | SVG;
    label: string;
};
type Item = CommonItemProps & {
    onSelect?: () => void;
    selectedByDefault?: boolean;
};
type GroupItem = CommonItemProps & {
    items: (Item | GroupItem)[];
};
type Section = {
    items: (Item | GroupItem)[];
    title?: string;
};
type Props$v = {
    /**
     * Array of items to be displayed in the Contextual menu.
     * Each item can be a single/simple item, a group item or a section.
     */
    items: (Item | GroupItem)[] | Section[];
};

declare function DxcContextualMenu({ items }: Props$v): react_jsx_runtime.JSX.Element;

type ActionCellsPropsType = {
    actions: ActionsPropsType;
};
type ActionsPropsType = Array<{
    icon: string | SVG;
    title: string;
    onClick: () => void;
    disabled?: boolean;
    tabIndex?: number;
    options?: never;
} | {
    icon?: never;
    title: string;
    onClick: (value?: string) => void;
    disabled?: boolean;
    tabIndex?: number;
    options: Option$1[];
}>;
type Props$u = {
    /**
     * The center section of the table. Can be used to render custom
     * content in this area.
     */
    children: ReactNode;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Determines the visual style and layout
     * - "default": Default table size.
     * - "reduced": More compact table with less spacing for high density information.
     */
    mode?: "default" | "reduced";
};

type GridColumn = {
    /**
     * Key that will be rendered from each row in rows.
     */
    key: string;
    /**
     * Label that will be used for the column header.
     */
    label: string;
    /**
     * Whether the column is resizable or not.
     */
    resizable?: boolean;
    /**
     * Whether the column is sortable or not.
     */
    sortable?: boolean;
    /**
     * Custom criteria for sorting the column.
     */
    sortFn?: (_a: ReactNode, _b: ReactNode) => 0 | 1 | -1;
    /**
     * Whether the column is draggable or not.
     */
    draggable?: boolean;
    /**
     * Whether the column cells are editable or not.
     */
    textEditable?: boolean;
    /**
     * Value that will be rendered from the summaryRow.
     */
    summaryKey?: string;
    /**
     * Sets the alignment inside the cells.
     */
    alignment?: "left" | "right" | "center";
};
type GridRow = {
    /**
     * List of rows that will be rendered in each cell based on the key in each column.
     */
    [key: string]: ReactNode | undefined;
};
type HierarchyGridRow = GridRow & {
    childRows?: HierarchyGridRow[] | GridRow[];
};
type ExpandableGridRow = GridRow & {
    expandedContent?: ReactNode;
    expandedContentHeight?: number;
    contentIsExpanded?: boolean;
};
type ExpandableRows = {
    rows: ExpandableGridRow[];
    /**
     * Whether the rows can expand or not.
     */
    expandable: true;
    /**
     * This prop indicates the unique key that can be used to identify each row. This prop is mandatory if selectable is set to true, expandable is set to true or rows is of type HierarchyGridRow[].
     */
    uniqueRowId: string;
};
type HierarchyRows = {
    rows: HierarchyGridRow[];
    /**
     * This prop indicates the unique key that can be used to identify each row. This prop is mandatory if selectable is set to true, expandable is set to true or rows is of type HierarchyGridRow[].
     */
    uniqueRowId: string;
    /**
     * Whether the rows can expand or not.
     */
    expandable?: false;
};
type SelectableGridProps = {
    /**
     * Whether the rows are selectable or not.
     */
    selectable: true;
    /**
     * Set of selected rows. This prop is mandatory if selectable is set to true. The uniqueRowId key will be used to identify the each row.
     */
    selectedRows: Set<string | number>;
    /**
     * Function called whenever the selected values changes. This prop is mandatory if selectable is set to true.The uniqueRowId key will be used to identify the rows.
     */
    onSelectRows: (selectedRows: Set<number | string>) => void;
    /**
     * This prop indicates the unique key that can be used to identify each row. This prop is mandatory if selectable is set to true, expandable is set to true or rows is of type HierarchyGridRow[].
     */
    uniqueRowId: string;
} | {
    selectable?: false;
    selectedRows?: never;
    onSelectRows?: never;
    uniqueRowId?: string;
};
type PaginatedProps$1 = {
    /**
     * If true, paginator will be displayed.
     */
    showPaginator?: true;
    /**
     * Number of total items.
     */
    totalItems?: number;
    /**
     * If true, a select component for navigation between pages will be displayed.
     */
    showGoToPage?: boolean;
    /**
     * Number of items per page.
     */
    itemsPerPage?: number;
    /**
     * An array of numbers representing the items per page options.
     */
    itemsPerPageOptions?: number[];
    /**
     * This function will be called when the user selects an item per page
     * option. The value selected will be passed as a parameter.
     */
    itemsPerPageFunction?: (value: number) => void;
    /**
     * Function called whenever the current page is changed.
     */
    onPageChange?: (_page: number) => void;
    /**
     * Default page in which the datagrid is rendered
     */
    defaultPage?: number;
};
type NonPaginatedProps$1 = {
    /**
     * If true, paginator will be displayed.
     */
    showPaginator: false;
    /**
     * Number of total items.
     */
    totalItems?: never;
    /**
     * If true, a select component for navigation between pages will be displayed.
     */
    showGoToPage?: never;
    /**
     * Number of items per page.
     */
    itemsPerPage?: never;
    /**
     * An array of numbers representing the items per page options.
     */
    itemsPerPageOptions?: never;
    /**
     * This function will be called when the user selects an item per page
     * option. The value selected will be passed as a parameter.
     */
    itemsPerPageFunction?: never;
    /**
     * Function called whenever the current page is changed.
     */
    onPageChange?: never;
    /**
     * Default page in which the datagrid is rendered
     */
    defaultPage?: never;
};
type CommonProps$6 = {
    columns: GridColumn[];
    /**
     * Extra row that will be always visible.
     */
    summaryRow?: GridRow;
    /**
     * Function called whenever a cell is edited.
     */
    onGridRowsChange?: (_rows: GridRow[] | HierarchyGridRow[] | ExpandableGridRow[]) => void;
    /**
     * Function called whenever a column is sorted. Receives the sorted
     * column and direction, or `undefined` if no sorting is applied.
     */
    onSort?: (_sortColumn?: SortColumn) => void;
};
type BasicGridProps = {
    rows: GridRow[];
    /**
     * Whether the rows can expand or not.
     */
    expandable?: false;
};
type Props$t = CommonProps$6 & (PaginatedProps$1 | NonPaginatedProps$1) & ((BasicGridProps & SelectableGridProps) | (ExpandableRows & SelectableGridProps) | (HierarchyRows & SelectableGridProps));

declare const DxcDataGrid: {
    ({ columns, rows, selectable, expandable, onSelectRows, selectedRows, uniqueRowId, summaryRow, onGridRowsChange, showPaginator, showGoToPage, itemsPerPage, itemsPerPageOptions, itemsPerPageFunction, onSort, onPageChange, totalItems, defaultPage, }: Props$t): JSX.Element;
    ActionsCell: ({ actions }: ActionCellsPropsType) => JSX.Element;
};

type Props$s = {
    /**
     * Initial value of the input element, only when it is uncontrolled.
     */
    defaultValue?: string;
    /**
     * Value of the input element. If undefined, the component will be uncontrolled and the value will be managed internally by the component.
     */
    value?: string;
    /**
     * Text to be placed above the date input.
     */
    label?: string;
    /**
     * Name attribute of the input element.
     */
    name?: string;
    /**
     * Helper text to be placed above the date.
     */
    helperText?: string;
    /**
     * If true, the date format will appear as placeholder in the field.
     */
    placeholder?: boolean;
    /**
     * The format in which the date value will be displayed. User must use this format when editing the value or it will be considered as an invalid date.
     */
    format?: string;
    /**
     * If true, the date input will have an action to clear the entered value.
     */
    clearable?: boolean;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * If true, the date will be optional, showing the text '(Optional)'
     * next to the label. Otherwise, the field will be considered required and an error will be
     * passed as a parameter to the OnBlur and onChange functions when it has
     * not been filled.
     */
    optional?: boolean;
    /**
     * If true, the component will not be mutable, meaning the user can not edit the control.
     * The date picker cannot be opened either. In addition, the clear action will not be displayed
     * even if the flag is set to true.
     */
    readOnly?: boolean;
    /**
     * This function will be called when the user types within the input
     * element of the component. An object including the string value, the
     * error and the date value will be passed to this function.
     * If the string value is a valid date, error will
     * be undefined. Also, if the string value is not a valid date, date will be undefined.
     */
    onChange?: (val: {
        value: string;
        error?: string;
        date?: Date;
    }) => void;
    /**
     * This function will be called when the input element loses the focus.
     * An object including the string value, the error and the date value
     * will be passed to this function. If the string value is a valid date, error will
     * be undefined. Also, if the string value is not a valid date, date will be undefined.
     */
    onBlur?: (val: {
        value: string;
        error?: string;
        date?: Date;
    }) => void;
    /**
     * If it is a defined value and also a truthy string, the component will
     * change its appearance, showing the error below the date input
     * component. If the defined value is an empty string, it will reserve a
     * space below the component for a future error, but it would not change
     * its look. In case of being undefined or null, both the appearance and
     * the space for the error message would not be modified.
     */
    error?: string;
    /**
     * HTML autocomplete attribute. Lets the user specify if any permission the user agent has to provide automated assistance in filling out the input value.
     * Its value must be one of all the possible values of the HTML autocomplete attribute: 'on', 'off', 'email', 'username', 'new-password', ...
     */
    autocomplete?: string;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent";
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the date input element when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcDateInput: react.ForwardRefExoticComponent<Props$s & react.RefAttributes<HTMLDivElement>>;

type Props$r = {
    /**
     * If true, the close button will be visible.
     */
    closable?: boolean;
    /**
     * This function will be called when the user clicks the close button.
     * The responsibility of hiding the dialog lies with the user.
     */
    onCloseClick?: () => void;
    /**
     * This function will be called when the user clicks on the background of the modal.
     * The responsibility of hiding the dialog lies with the user.
     */
    onBackgroundClick?: () => void;
    /**
     * If true, the dialog will be displayed over a darker background that covers the content behind.
     */
    overlay?: boolean;
    /**
     * Area within the dialog that can be used to render custom content.
     * We strongly encourage users to not change the
     * tabindex of the inner components or elements. This
     * can lead to unpredictable behaviour for keyboard users, affecting
     * the order of focus and focus locking within the dialog.
     */
    children: ReactNode;
    /**
     * Value of the tabindex applied to the close button.
     * Note that values greater than 0 are strongly discouraged. It can
     * lead to unexpected behaviours with the focus within the dialog.
     */
    tabIndex?: number;
};

declare const DxcDialog: ({ children, closable, onBackgroundClick, onCloseClick, overlay, tabIndex, }: Props$r) => JSX.Element;

type Props$q = {
    /**
     * The divider can be shown in horizontal or vertical.
     */
    orientation?: "horizontal" | "vertical";
    /**
     * Modifies the thickness of the divider.
     */
    weight?: "regular" | "strong";
    /**
     * Modifies the color of the divider.
     */
    color?: "lightGrey" | "mediumGrey" | "darkGrey";
    /**
     * Specifies whether the divider serves a purely decorative purpose
     * or functions as a semantic separator for content. Additionally, it
     * determines whether the divider is accessible to screen readers.
     */
    decorative?: boolean;
};

declare const DxcDivider: ({ orientation, weight, color, decorative, }: Props$q) => JSX.Element;

declare const DxcDropdown: ({ options, optionsIconPosition, icon, iconPosition, label, caretHidden, disabled, expandOnHover, onSelectOption, margin, size, tabIndex, title, }: Props$G) => JSX.Element;

type FileData = {
    /**
     * Selected file.
     */
    file: File;
    /**
     * Error of the file. If it is defined, it will be shown and the file item will be mark as invalid.
     */
    error?: string;
    /**
     * Preview of the file.
     */
    preview?: string;
};
type CommonProps$5 = {
    /**
     * Text to be placed above the component.
     */
    label?: string;
    /**
     * Text to be placed inside the button.
     */
    buttonLabel?: string;
    /**
     * Helper text to be placed above the component.
     */
    helperText?: string;
    /**
     * The file types that the component accepts. Its value must be one of all the possible values of the HTML file input's accept attribute.
     */
    accept?: string;
    /**
     * An array of files representing the selected files.
     */
    value: FileData[];
    /**
     * The minimum file size (in bytes) allowed. If the size of the file does not comply the minSize, the file will have an error.
     */
    minSize?: number;
    /**
     * The maximum file size (in bytes) allowed. If the size of the file does not comply the maxSize, the file will have an error.
     */
    maxSize?: number;
    /**
     * If true, if the file is an image, a preview of it will be shown. If not, an icon refering to the file type will be shown.
     */
    showPreview?: boolean;
    /**
     * If true, the component allows multiple file items and will show all of them. If false, only one file will be shown, and if there is already one
     *  file selected and a new one is chosen, it will be replaced by the new selected one.
     */
    multiple?: boolean;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * This function will be called when the user selects or drops a file. The list of files will be sent as a parameter.
     * In this function, the files can be updated or returned as they come. These files must be passed to the value in order to be shown.
     */
    callbackFile: (files: FileData[]) => void;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
};
type DropModeProps = CommonProps$5 & {
    /**
     * Uses one of the available file input modes:
     *    'file': Files are selected by clicking the button and selecting it through the file explorer.
     *    'filedrop': Files can be selected by clicking the button and selecting it through the file explorer or by dropping them inside the drag and drop area.
     *    'dropzone':  Files can be selected by clicking the button and selecting it through the file explorer or by dropping them inside the drag and drop area.
     *     The drag and drop area of this mode is bigger than the one of the filedrop mode.
     */
    mode: "filedrop" | "dropzone";
    /**
     * Text to be placed inside the drag and drop zone alongside the button.
     */
    dropAreaLabel?: string;
};
type FileModeProps = CommonProps$5 & {
    /**
     * Uses one of the available file input modes:
     *    'file': Files are selected by clicking the button and selecting it through the file explorer.
     *    'filedrop': Files can be selected by clicking the button and selecting it through the file explorer or by dropping them inside the drag and drop area.
     *    'dropzone':  Files can be selected by clicking the button and selecting it through the file explorer or by dropping them inside the drag and drop area.
     *     The drag and drop area of this mode is bigger than the one of the filedrop mode.
     */
    mode?: "file";
    /**
     * Text to be placed inside the drag and drop zone alongside the button.
     */
    dropAreaLabel?: never;
};
type Props$p = DropModeProps | FileModeProps;

declare const DxcFileInput: react.ForwardRefExoticComponent<Props$p & react.RefAttributes<HTMLDivElement>>;

type Gap$1 = {
    rowGap: CoreSpacingTokensType;
    columnGap?: CoreSpacingTokensType;
} | {
    rowGap?: CoreSpacingTokensType;
    columnGap: CoreSpacingTokensType;
} | CoreSpacingTokensType;
type CommonProps$4 = {
    /**
     * Sets the justify-content CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/justify-content
     */
    justifyContent?: "flex-start" | "flex-end" | "start" | "end" | "left" | "normal" | "right" | "center" | "space-between" | "space-around" | "space-evenly";
    /**
     * Sets the align-items CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/align-items
     */
    alignItems?: "stretch" | "flex-start" | "flex-end" | "start" | "end" | "self-start" | "self-end" | "center" | "baseline" | "normal";
    /**
     * Sets the align-content CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/align-content
     */
    alignContent?: "normal" | "flex-start" | "flex-end" | "start" | "end" | "center" | "space-between" | "space-around" | "space-evenly" | "stretch";
    /**
     * Sets the align-self CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/align-self
     */
    alignSelf?: "auto" | "flex-start" | "flex-end" | "center" | "baseline" | "stretch";
};
type Props$o = CommonProps$4 & {
    /**
     * Sets the flex-direction CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/flex-direction
     */
    direction?: "row" | "row-reverse" | "column" | "column-reverse";
    /**
     * Sets the flex-wrap CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/flex-wrap
     */
    wrap?: "nowrap" | "wrap" | "wrap-reverse";
    /**
     * Sets the gap CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/gap
     */
    gap?: Gap$1;
    /**
     * Sets the order CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/order
     */
    order?: number;
    /**
     * Sets the flex-grow CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/flex-grow
     */
    grow?: number;
    /**
     * Sets the flex-shrink CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/flex-shrink
     */
    shrink?: number;
    /**
     * Sets the flex-basis CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/flex-basis
     */
    basis?: string;
    /**
     * Sets a custom HTML tag.
     */
    as?: keyof HTMLElementTagNameMap;
    /**
     * Custom content inside the flex container.
     */
    children: ReactNode;
};

declare const DxcFlex: ({ basis, direction, gap, grow, order, shrink, wrap, ...props }: Props$o) => react_jsx_runtime.JSX.Element;

type Gap = {
    rowGap: CoreSpacingTokensType;
    columnGap?: CoreSpacingTokensType;
} | {
    rowGap?: CoreSpacingTokensType;
    columnGap: CoreSpacingTokensType;
} | CoreSpacingTokensType;
type GridCell = {
    start: number | string;
    end: number | string;
};
type PlaceSelfValues = "auto" | "start" | "end" | "center" | "stretch" | "baseline";
type PlaceContentValues = "normal" | "start" | "end" | "center" | "stretch" | "space-between" | "space-around" | "space-evenly" | "baseline";
type PlaceItemsValues = "normal" | "start" | "end" | "center" | "stretch" | "baseline";
type PlaceObject<Type, Suffix extends string> = {
    [Property in keyof Type as `${string & Property}${Capitalize<string & Suffix>}`]: Type[Property];
};
type PlaceGeneric<PlaceValues, Element extends string> = PlaceObject<{
    justify?: PlaceValues;
    align: PlaceValues;
}, Element> | PlaceObject<{
    justify: PlaceValues;
    align?: PlaceValues;
}, Element> | PlaceValues;
type GridItemProps = {
    /**
     * Sets the name of an item so that it can be referenced by a template created with the grid-template-areas property.
     */
    areaName?: string;
    /**
     * Sets the grid-column CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/grid-column
     */
    column?: number | string | GridCell;
    /**
     * Sets the grid-row CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/grid-row
     */
    row?: number | string | GridCell;
    /**
     * Sets the place-self CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/place-self
     */
    placeSelf?: PlaceGeneric<PlaceSelfValues, "self">;
    /**
     * Sets a custom HTML tag.
     */
    as?: keyof HTMLElementTagNameMap;
    /**
     * Custom content inside the grid container.
     */
    children: ReactNode;
};
type Props$n = GridItemProps & {
    /**
     * Sets the grid-auto-columns CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/grid-auto-columns
     */
    autoColumns?: string;
    /**
     * Sets the grid-auto-flow CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/grid-auto-flow
     */
    autoFlow?: "row" | "column" | "row dense" | "column dense";
    /**
     * Sets the grid-auto-rows CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/grid-auto-rows
     */
    autoRows?: string;
    /**
     * Sets the gap CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/gap
     */
    gap?: CoreSpacingTokensType | Gap;
    /**
     * Sets the place-content CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/place-content
     */
    placeContent?: PlaceGeneric<PlaceContentValues, "content">;
    /**
     * Sets the place-items CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/place-items
     */
    placeItems?: PlaceGeneric<PlaceItemsValues, "items">;
    /**
     * Sets the grid-template-areas CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-areas
     */
    templateAreas?: string[];
    /**
     * Sets the grid-template-columns CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-columns
     */
    templateColumns?: string[];
    /**
     * Sets the grid-template-rows CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-rows
     */
    templateRows?: string[];
};

declare const DxcGrid: {
    (props: Props$n): react_jsx_runtime.JSX.Element;
    Item: styled_components.StyledComponent<"div", any, GridItemProps, never>;
};

type Props$m = {
    /**
     * Defines the heading level from 1 to 5. The styles of the heading are applied according to the level.
     * The html tag of the heading will be the one specified in the 'as' prop.
     * If 'as' is not specified, the html tag of the heading is the one specified in the 'level' prop.
     */
    level?: 1 | 2 | 3 | 4 | 5;
    /**
     * Heading text.
     */
    text: string;
    /**
     * Modifies the default weight of the heading.
     */
    weight?: "light" | "normal" | "bold";
    /**
     * Specifies the HTML tag of the heading.
     */
    as?: "h1" | "h2" | "h3" | "h4" | "h5";
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
};

declare const DxcHeading: ({ level, text, as, weight, margin }: Props$m) => JSX.Element;

type Props$l = {
    /**
     * Alternative text description displayed when the specified image is not loaded.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/API/HTMLImageElement/alt
     * See W3C alt decision tree: https://www.w3.org/WAI/tutorials/images/decision-tree/
     */
    alt: string;
    /**
     * Image legend with a descriptive purpose. It is placed below the image and is complementary to the alt attribute,
     * which is required regardless of the presence of the caption or not.
     */
    caption?: string;
    /**
     * If true, the image will be loaded only when it is visible on the screen (lazy loading).
     * Otherwise and by default, the image will be loaded as soon as the component is mounted (eager loading).
     */
    lazyLoading?: boolean;
    /**
     * URL of the image. This prop is required and must be valid.
     */
    src: string;
    /**
     * List of one or more strings separated by commas indicating a set of possible images for the user agent to use.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/API/HTMLImageElement/srcset
     */
    srcSet?: string;
    /**
     * One or more strings separated by commas, indicating a set of source sizes.
     * If the srcSet attribute is absent or contains no values with a width descriptor,
     * then this attribute has no effect.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/API/HTMLImageElement/sizes
     */
    sizes?: string;
    /**
     * Sets the rendered width of the image.
     */
    width?: string;
    /**
     * Sets the rendered height of the image.
     */
    height?: string;
    /**
     * Sets the object-fit CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/object-fit
     */
    objectFit?: "contain" | "cover" | "fill" | "none" | "scale-down";
    /**
     * Sets the object-position CSS property.
     *
     * See MDN: https://developer.mozilla.org/en-US/docs/Web/CSS/object-position
     */
    objectPosition?: string;
    /**
     * This function will be called when the image is loaded.
     */
    onLoad?: ReactEventHandler<HTMLImageElement>;
    /**
     * This function will be called when the image fails to load.
     */
    onError?: ReactEventHandler<HTMLImageElement>;
};

declare function DxcImage({ alt, caption, lazyLoading, src, srcSet, sizes, width, height, objectFit, objectPosition, onLoad, onError, }: Props$l): react_jsx_runtime.JSX.Element;

type Props$k = {
    /**
     * Applies the spacing scale to all sides.
     */
    space?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the left and right sides.
     */
    horizontal?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the top and bottom sides.
     */
    vertical?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the top side.
     */
    top?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the right side.
     */
    right?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the bottom side.
     */
    bottom?: CoreSpacingTokensType;
    /**
     * Applies the spacing scale to the left side.
     */
    left?: CoreSpacingTokensType;
    /**
     * Custom content inside the inset.
     */
    children: ReactNode;
};

declare const Inset: ({ space, horizontal, vertical, top, right, bottom, left, children }: Props$k) => react_jsx_runtime.JSX.Element;

type LinkProps = {
    /**
     * If true, the link is disabled.
     */
    disabled?: boolean;
    /**
     * If true, the color is inherited from parent.
     */
    inheritColor?: boolean;
    /**
     * Material Symbol name or SVG element as the icon that will be placed next to the link text.
     */
    icon?: string | SVG;
    /**
     * Indicates the position of the icon in the component.
     */
    iconPosition?: "before" | "after";
    /**
     * Page to be opened when the user clicks on the link.
     */
    href?: string;
    /**
     * If true, the page is opened in a new browser tab.
     */
    newWindow?: boolean;
    /**
     * If defined, the link will be displayed as a button. This
     * function will be called when the user clicks the link.
     */
    onClick?: () => void;
    /**
     * Text of the link.
     */
    children: string;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Value of the tabindex.
     */
    tabIndex?: number;
};

declare const DxcLink: react.ForwardRefExoticComponent<LinkProps & react.RefAttributes<HTMLAnchorElement>>;

type TabProps$1 = {
    /**
     * Whether the tab is active or not.
     */
    active?: boolean;
    /**
     * Whether the tab is disabled or not.
     */
    disabled?: boolean;
    /**
     * Page to be opened when the user clicks on the tab.
     */
    href?: string;
    /**
     * Material Symbol name or SVG element used as the icon that will be displayed in the tab.
     */
    icon?: string | SVG;
    /**
     * If the value is 'true', an empty badge will appear.
     * If it is 'false', no badge will appear.
     * If a number is put it will be shown as the label of the notification
     * in the tab, taking into account that if that number is greater than 99,
     * it will appear as '+99' in the badge.
     */
    notificationNumber?: boolean | number;
    /**
     * Tab text label.
     */
    children: string;
};
type Props$j = {
    /**
     * Whether the icon should appear above or to the left of the label.
     */
    iconPosition?: "top" | "left";
    /**
     * Contains one or more DxcNavTabs.Tab.
     */
    children: ReactNode;
    /**
     * Value of the tabindex attribute applied to each tab.
     */
    tabIndex?: number;
};

declare const DxcNavTabs: {
    ({ iconPosition, tabIndex, children }: Props$j): JSX.Element;
    Tab: react.ForwardRefExoticComponent<TabProps$1 & react.RefAttributes<HTMLAnchorElement>>;
};

type Props$i = {
    /**
     * Text to be placed above the number.
     */
    label?: string;
    /**
     * Name attribute of the input element.
     */
    name?: string;
    /**
     * Initial value of the input element, only when it is uncontrolled.
     */
    defaultValue?: string;
    /**
     * Value of the input element. If undefined, the component will be uncontrolled and the value will be managed internally by the component.
     */
    value?: string;
    /**
     * Helper text to be placed above the number.
     */
    helperText?: string;
    /**
     * Text to be put as placeholder of the number.
     */
    placeholder?: string;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * If true, the number will be optional, showing the text '(Optional)'
     * next to the label. Otherwise, the field will be considered required
     * and an error will be passed as a parameter to the OnBlur and onChange
     * functions when it has not been filled.
     */
    optional?: boolean;
    /**
     * If true, the component will not be mutable, meaning the user can
     * not edit the control. The value won't change when pressing on the
     * up or down arrows and neither on the spin buttons.
     */
    readOnly?: boolean;
    /**
     * Prefix to be placed before the number value.
     */
    prefix?: string;
    /**
     * Suffix to be placed after the number value.
     */
    suffix?: string;
    /**
     * Minimum value allowed by the number input. If the typed value by the user is
     * lower than min, the onBlur and onChange functions will be called with
     * the current value and an internal error informing that the current
     * value is not correct. If a valid state is reached, the error parameter
     * will not be defined in both events.
     */
    min?: number;
    /**
     * Maximum value allowed by the number input. If the typed value by the user
     * surpasses max, the onBlur and onChange functions will be called with
     * the current value and an internal error informing that the current
     * value is not correct. If a valid state is reached, the error parameter
     * will not be defined in both events.
     */
    max?: number;
    /**
     * The step interval to use when using the up and down arrows to adjust the value.
     */
    step?: number;
    /**
     * This function will be called when the user types within the input
     * element of the component. An object including the current value and
     * the error (if the value entered is not valid) will be passed to this
     * function. If there is no error, error will not be defined.
     */
    onChange?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * This function will be called when the input element loses the focus.
     * An object including the input value and the error (if the value
     * entered is not valid) will be passed to this function. If there is no error,
     * error will not be defined.
     */
    onBlur?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * If it is a defined value and also a truthy string, the component will
     * change its appearance, showing the error below the input component. If
     * the defined value is an empty string, it will reserve a space below
     * the component for a future error, but it would not change its look. In
     * case of being undefined or null, both the appearance and the space for
     * the error message would not be modified.
     */
    error?: string;
    /**
     * HTML autocomplete attribute. Lets the user specify if any permission the user agent has to provide automated assistance in filling out the input value.
     * Its value must be one of all the possible values of the HTML autocomplete attribute: 'on', 'off', 'email', 'username', 'new-password', ...
     */
    autocomplete?: string;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent";
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the number input element when no `label` is provided.
     */
    ariaLabel?: string;
    /**
     * Decides whether the number input has actions to increase or decrease the value, following the defined step.
     */
    showControls?: boolean;
};

declare const DxcNumberInput: react.ForwardRefExoticComponent<Props$i & react.RefAttributes<HTMLDivElement>>;

type Props$h = {
    /**
     * Number of the current selected page.
     */
    currentPage?: number;
    /**
     * Number of items per page.
     */
    itemsPerPage?: number;
    /**
     * Array of numbers representing the items per page options.
     * If undefined, the select with items per page options will not be displayed.
     */
    itemsPerPageOptions?: number[];
    /**
     * This function will be called when the user selects an item per page option.
     * The number will be passed as a parameter to this function.
     */
    itemsPerPageFunction?: (itemsPerPage: number) => void;
    /**
     * Total number of items in the pages.
     */
    totalItems?: number;
    /**
     * If true, a select will be displayed with the page numbers to move through them.
     */
    showGoToPage?: boolean;
    /**
     * This function will be called when the user clicks on any of the button to change pages.
     * The page number will be passed as a parameter to this function.
     */
    onPageChange?: (page: number) => void;
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
};

declare const DxcPaginator: ({ currentPage, itemsPerPage, itemsPerPageOptions, totalItems, showGoToPage, onPageChange, itemsPerPageFunction, tabIndex, }: Props$h) => JSX.Element;

declare function DxcParagraph({ children }: {
    children: ReactNode;
}): react_jsx_runtime.JSX.Element;

type Props$g = {
    /**
     * Text to be placed above the password input.
     */
    label?: string;
    /**
     * Name attribute of the input element.
     */
    name?: string;
    /**
     * Value of the input element. If undefined, the component will be uncontrolled and the value will be managed internally by the component.
     */
    value?: string;
    /**
     * Helper text to be placed above the password.
     */
    helperText?: string;
    /**
     * If true, the password input will have an action to clear the entered value.
     */
    clearable?: boolean;
    /**
     * This function will be called when the user types within the input
     * element of the component. An object including the current value and
     * the error (if the value entered is not valid) will be passed to this
     * function. If there is no error, error will not be defined.
     * */
    onChange?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * This function will be called when the input element loses the focus.
     * An object including the input value and the error (if the value entered is
     * not valid) will be passed to this function. If there is no error, error will
     * not be defined.
     */
    onBlur?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * If it is a defined value and also a truthy string, the component will
     * change its appearance, showing the error below the password input
     * component. If the defined value is an empty string, it will reserve a
     * space below the component for a future error, but it would not change
     * its look. In case of being undefined or null, both the appearance and
     * the space for the error message would not be modified.
     */
    error?: string;
    /**
     * Regular expression that defines the valid format allowed by the
     * password input. This will be checked both when the input element loses the
     * focus and while typing within it. If the string entered does not match
     * the pattern, the onBlur and onChange functions will be called with the
     * current value and an internal error informing that this value does not
     * match the pattern. If the pattern is met, the error parameter of both
     * events will not be defined.
     */
    pattern?: string;
    /**
     * Specifies the minimum length allowed by the password input.
     * This will be checked both when the input element loses the
     * focus and while typing within it. If the string entered does not
     * comply the minimum length, the onBlur and onChange functions will be called
     * with the current value and an internal error informing that the value
     * length does not comply the specified range. If a valid length is
     * reached, the error parameter of both events will not be defined.
     */
    minLength?: number;
    /**
     * Specifies the maximum length allowed by the password input.
     * This will be checked both when the input element loses the
     * focus and while typing within it. If the string entered does not
     * comply the maximum length, the onBlur and onChange functions will be called
     * with the current value and an internal error informing that the value
     * length does not comply the specified range. If a valid length is
     * reached, the error parameter of both events will not be defined.
     */
    maxLength?: number;
    /**
     * HTML autocomplete attribute. Lets the user specify if any permission the user agent has to provide automated assistance in filling out the input value.
     * Its value must be one of all the possible values of the HTML autocomplete attribute: 'on', 'off', 'email', 'username', 'new-password', ...
     */
    autocomplete?: string;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent";
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the password input element when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcPasswordInput: react.ForwardRefExoticComponent<Props$g & react.RefAttributes<HTMLDivElement>>;

type Size$1 = {
    top?: Space$1;
    bottom?: Space$1;
    left?: Space$1;
    right?: Space$1;
};
type Props$f = {
    /**
     * Text to be placed above the progress bar.
     */
    label?: string;
    /**
     * Helper text to be placed under the progress bar.
     */
    helperText?: string;
    /**
     * If true, the progress bar will be displayed as a modal.
     */
    overlay?: boolean;
    /**
     * The value of the progress indicator. If it's received the component is
     * determinate otherwise is indeterminate.
     */
    value?: number;
    /**
     * If true, the value is displayed above the progress bar.
     */
    showValue?: boolean;
    /**
     * Size of the margin to be applied to the component. You can pass
     * an object with 'top', 'bottom', 'left' and 'right' properties
     * in order to specify different margin sizes.
     */
    margin?: Space$1 | Size$1;
    /**
     * Specifies a string to be used as the name for the progress bar element when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcProgressBar: ({ label, helperText, overlay, value, showValue, margin, ariaLabel, }: Props$f) => JSX.Element;

type Link = {
    /**
     * Label to be shown in the link.
     */
    label: string;
    /**
     * Sublinks of the link.
     */
    links?: Link[];
};
type Props$e = {
    /**
     * Title of the quick nav component.
     */
    title?: string;
    /**
     * Links to be shown inside the quick nav component.
     */
    links: Link[];
};

declare const DxcQuickNav: ({ title, links }: Props$e) => JSX.Element;

type RadioOption = {
    /**
     * Label of the option placed next to the radio input.
     */
    value: string;
    /**
     * Value of the option. It should be unique and
     * not an empty string, which is reserved to the optional item added
     * by 'optional' prop.
     */
    label: string;
    /**
     * If true, disables the option.
     */
    disabled?: boolean;
};
type RadioGroupProps = {
    /**
     * Text to be placed above the radio group.
     */
    label?: string;
    /**
     * Name attribute of the input element. This attribute will allow users
     * to find the component's value during the submit event.
     */
    name?: string;
    /**
     * Helper text to be placed above the radio group.
     */
    helperText?: string;
    /**
     * An array of objects representing the selectable options.
     */
    options: RadioOption[];
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * If true, the radio group will be optional, showing
     * (Optional) next to the label and adding a default last
     * option with an empty string as value. Otherwise, the field will be
     * considered required and an error will be passed as a parameter to the
     * OnBlur functions if an option wasn't selected.
     */
    optional?: boolean;
    /**
     * Label of the optional radio input.
     */
    optionalItemLabel?: string;
    /**
     * If true, the component will not be mutable, meaning the user can not edit the control.
     */
    readOnly?: boolean;
    /**
     * Sets the orientation of the options within the radio group.
     */
    stacking?: "row" | "column";
    /**
     * Initial value of the radio group, only when it is uncontrolled.
     */
    defaultValue?: string;
    /**
     * Value of the radio group. If undefined, the component will be
     * uncontrolled and the value will be managed internally by the
     * component.
     */
    value?: string;
    /**
     * This function will be called when the user chooses an option. The new
     * value will be passed to this function.
     */
    onChange?: (value: string) => void;
    /**
     * This function will be called when the radio group loses the focus. An
     * object including the value and the error will be passed to this
     * function. If there is no error, error will not be defined.
     */
    onBlur?: (val: {
        value?: string;
        error?: string;
    }) => void;
    /**
     * If it is a defined value and also a truthy string, the component will
     * change its appearance, showing the error below the radio group. If the
     * defined value is an empty string, it will reserve a space below the
     * component for a future error, but it would not change its look. In
     * case of being undefined or null, both the appearance and the space for
     * the error message would not be modified.
     */
    error?: string;
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the radio group when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcRadioGroup: react.ForwardRefExoticComponent<RadioGroupProps & react.RefAttributes<HTMLDivElement>>;

type Column = {
    /**
     * Column display value.
     */
    displayValue: ReactNode;
    /**
     * Boolean value to indicate whether the column is sortable or not.
     */
    isSortable?: boolean;
};
type Cell = {
    /**
     * Value to be displayed in the cell.
     */
    displayValue: ReactNode;
    /**
     * Value to be used when sorting the table by that
     * column. If not indicated displayValue will be used for sorting.
     */
    sortValue?: string | number | Date;
};
type Row = Cell[];
type CommonProps$3 = {
    /**
     * An array of objects representing the columns of the table.
     */
    columns: Column[];
    /**
     * An array of objects representing the rows of the table, you will have
     * as many objects as columns in the table.
     */
    rows: Row[];
    /**
     * Size of the margin to be applied to the component. You can pass an object with 'top',
     * 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Value of the tabindex attribute applied to the sortable icon.
     */
    tabIndex?: number;
    /**
     * Determines the visual style and layout
     * - "default": The default mode with big spacing
     * - "reduced": A reduced mode with minimal spacing for dense tables
     */
    mode?: "default" | "reduced";
};
type PaginatedProps = CommonProps$3 & {
    hidePaginator?: false;
    /**
     * If true, a select component for navigation between pages will be displayed.
     */
    showGoToPage?: boolean;
    /**
     * Number of items per page.
     */
    itemsPerPage?: number;
    /**
     * An array of numbers representing the items per page options.
     */
    itemsPerPageOptions?: number[];
    /**
     * This function will be called when the user selects an item per page
     * option. The value selected will be passed as a parameter.
     */
    itemsPerPageFunction?: (value: number) => void;
};
type NonPaginatedProps = CommonProps$3 & {
    /**
     * If true, paginator will not be displayed.
     */
    hidePaginator: true;
    /**
     * If true, a select component for navigation between pages will be displayed.
     */
    showGoToPage?: never;
    /**
     * Number of items per page.
     */
    itemsPerPage?: never;
    /**
     * An array of numbers representing the items per page options.
     */
    itemsPerPageOptions?: never;
    /**
     * This function will be called when the user selects an item per page
     * option. The value selected will be passed as a parameter.
     */
    itemsPerPageFunction?: never;
};
type Props$d = PaginatedProps | NonPaginatedProps;

declare const DxcResultsetTable: {
    ({ columns, rows, hidePaginator, showGoToPage, itemsPerPage, itemsPerPageOptions, itemsPerPageFunction, margin, tabIndex, mode, }: Props$d): JSX.Element;
    ActionsCell: ({ actions }: ActionCellsPropsType) => JSX.Element;
};

type ListOptionGroupType = {
    /**
     * Label of the group to be shown in the select's listbox.
     */
    label: string;
    /**
     * List of the grouped options.
     */
    options: ListOptionType[];
};
type ListOptionType = {
    /**
     * Element used as the icon that will be placed before the option label.
     * It can be an inline SVG or Material Symbol name. If the url option
     * is the chosen one, take into account that the component's
     * color styling tokens will not be applied to the image.
     */
    icon?: string | SVG;
    /**
     * Label of the option to be shown in the select's listbox.
     */
    label: string;
    /**
     * Value of the option. It should be unique and
     * not an empty string, which is reserved to the empty option added
     * by optional prop.
     */
    value: string;
};
type CommonProps$2 = {
    /**
     * Text to be placed above the select.
     */
    label?: string;
    /**
     * Name attribute of the input element. This attribute will allow users
     * to find the component's value during the submit event. In this event,
     * the component's value will always be a regular string, for both single
     * and multiple selection modes, being a single option value in the first case
     * and more than one value when multiple selection is available, separated by commas.
     */
    name?: string;
    /**
     * An array of objects representing the selectable options.
     */
    options: ListOptionType[] | ListOptionGroupType[];
    /**
     * Helper text to be placed above the select.
     */
    helperText?: string;
    /**
     * Text to be put as placeholder of the select.
     */
    placeholder?: string;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * If true, the select will be optional, showing '(Optional)'
     * next to the label and adding a default first option with an empty string as value,
     * been the placeholder (if defined) its label. Otherwise, the field will be
     * considered required and an error will be passed as a parameter to the
     * OnBlur and onChange functions if an option wasn't selected.
     */
    optional?: boolean;
    /**
     * If true, enables search functionality.
     */
    searchable?: boolean;
    /**
     * If it is a defined value and also a truthy string, the component will
     * change its appearance, showing the error below the select component.
     * If the defined value is an empty string, it will reserve a space below
     * the component for a future error, but it would not change its look. In
     * case of being undefined or null, both the appearance and the space for
     * the error message would not be modified.
     */
    error?: string;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent";
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the select element when no `label` is provided.
     */
    ariaLabel?: string;
};
type SingleSelect = CommonProps$2 & {
    /**
     * If true, the select component will support multiple selected options.
     * In that case, value will be an array of strings with each selected
     * option value.
     */
    multiple?: false;
    /**
     * Initial value of the select, only when it is uncontrolled.
     */
    defaultValue?: string;
    /**
     * Value of the select. If undefined, the component will be uncontrolled
     * and the value will be managed internally by the component.
     */
    value?: string;
    /**
     * This function will be called when the user selects an option.
     * An object including the current value and the error (if the value entered is not valid)
     * will be passed to this function. If there is no error, error will not be defined.
     */
    onChange?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * This function will be called when the select loses the focus. An
     * object including the value and the error (if the value
     * selected is not valid) will be passed to this function. If there is no error,
     * error will not be defined.
     */
    onBlur?: (val: {
        value: string;
        error?: string;
    }) => void;
};
type MultipleSelect = CommonProps$2 & {
    /**
     * If true, the select component will support multiple selected options.
     * In that case, value will be an array of strings with each selected
     * option value.
     */
    multiple: true;
    /**
     * Initial value of the select, only when it is uncontrolled.
     */
    defaultValue?: string[];
    /**
     * Value of the select. If undefined, the component will be uncontrolled
     * and the value will be managed internally by the component.
     */
    value?: string[];
    /**
     * This function will be called when the user selects an option.
     * An object including the current selected values and the error (if the value entered is not valid)
     * will be passed to this function. If there is no error, error will be null.
     */
    onChange?: (val: {
        value: string[];
        error?: string;
    }) => void;
    /**
     * This function will be called when the select loses the focus. An
     * object including the selected values and the error (if the value
     * selected is not valid) will be passed to this function. If there is no error,
     * error will be null.
     */
    onBlur?: (val: {
        value: string[];
        error?: string;
    }) => void;
};
type Props$c = SingleSelect | MultipleSelect;

declare const DxcSelect: react.ForwardRefExoticComponent<Props$c & react.RefAttributes<HTMLDivElement>>;

type Props$b = {
    /**
     * Text to be placed above the slider.
     */
    label?: string;
    /**
     * Name attribute of the input element.
     */
    name?: string;
    /**
     * Initial value of the slider, only when it is uncontrolled.
     */
    defaultValue?: number;
    /**
     * The selected value. If undefined, the component will be uncontrolled and the value will be managed internally by the component.
     */
    value?: number;
    /**
     * Helper text to be placed above the slider.
     */
    helperText?: string;
    /**
     * The minimum value available for selection.
     */
    minValue?: number;
    /**
     * The maximum value available for selection.
     */
    maxValue?: number;
    /**
     * The step interval between values available for selection.
     */
    step?: number;
    /**
     * Whether the min/max value labels should be displayed next to the slider
     */
    showLimitsValues?: boolean;
    /**
     * Whether the input element for displaying/controlling the slider value should be displayed next to the slider.
     */
    showInput?: boolean;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * Whether the marks between each step should be shown or not.
     */
    marks?: boolean;
    /**
     * This function will be called when the slider changes its value, as it's being dragged.
     * The new value will be passed as a parameter when this function is executed.
     */
    onChange?: (value: number) => void;
    /**
     * This function will be called when the slider changes its value, but only when the thumb is released.
     * The new value will be passed as a parameter when this function is executed.
     */
    onDragEnd?: (value: number) => void;
    /**
     * This function will be used to format the labels displayed next to the slider.
     * The value will be passed as parameter and the function must return the formatted value.
     */
    labelFormatCallback?: (value: number) => string;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "medium" | "large" | "fillParent";
    /**
     * Specifies a string to be used as the name for the slider element when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcSlider: react.ForwardRefExoticComponent<Props$b & react.RefAttributes<HTMLDivElement>>;

type Props$a = {
    /**
     * Text to be placed inside the spinner.
     */
    label?: string;
    /**
     * The value of the progress indicator. If it's received the
     * component is determinate, otherwise is indeterminate.
     */
    value?: number;
    /**
     * If true, the value is displayed inside the spinner..
     */
    showValue?: boolean;
    /**
     * Available modes of the spinner.
     */
    mode?: "large" | "small" | "overlay";
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Specifies a string to be used as the name for the spinner element when no `label` is provided or the `mode` is set to small.
     */
    ariaLabel?: string;
};

declare const DxcSpinner: ({ label, value, showValue, mode, margin, ariaLabel, }: Props$a) => JSX.Element;

type Mode = "default" | "info" | "success" | "warning" | "error";
type Size = "small" | "medium" | "large";
type Props$9 = {
    /**
     * It will define the color of the light based on its semantic meaning.
     */
    mode?: Mode;
    /**
     * An auxiliar text that will add some context to the status.
     */
    label: string;
    /**
     *  Size of the component. Should be defined based on its importance and/or available space.
     */
    size?: Size;
};

declare const DxcStatusLight: ({ mode, label, size }: Props$9) => JSX.Element;

type Props$8 = {
    /**
     * Initial state of the switch, only when it is uncontrolled.
     */
    defaultChecked?: boolean;
    /**
     * If true, the component is checked. If undefined, the component will be uncontrolled
     * and the checked attribute will be managed internally by the component.
     */
    checked?: boolean;
    /**
     * Will be passed to the value attribute of the html input element. When inside a form,
     * this value will be only submitted if the switch is checked.
     */
    value?: string;
    /**
     * Text to be placed next to the switch.
     */
    label?: string;
    /**
     * Whether the label should appear after or before the switch.
     */
    labelPosition?: "before" | "after";
    /**
     * Name attribute of the input element.
     */
    name?: string;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * This function will be called when the user changes the state of the switch.
     * The new value of the checked attribute will be passed as a parameter.
     */
    onChange?: (checked: boolean) => void;
    /**
     * If true, the component will display '(Optional)' next to the label.
     */
    optional?: boolean;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent" | "fitContent";
    /**
     * Value of the tabindex.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the switch element when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcSwitch: react.ForwardRefExoticComponent<Props$8 & react.RefAttributes<HTMLDivElement>>;

declare const DxcTable: {
    ({ children, margin, mode }: Props$u): JSX.Element;
    ActionsCell: ({ actions }: ActionCellsPropsType) => JSX.Element;
};

type TabCommonProps = {
    /**
     * Whether the tab is disabled or not.
     */
    isDisabled?: boolean;
    /**
     * If the value is 'true', an empty badge will appear.
     * If it is 'false', no badge will appear.
     * If a number is put it will be shown as the label of the notification
     * in the tab, taking into account that if that number is greater than 99,
     * it will appear as '+99' in the badge.
     */
    notificationNumber?: boolean | number;
};
type TabLabelProps = {
    /**
     * Tab label.
     */
    label: string;
    /**
     * Material Symbol name or SVG element used as the icon that will be displayed in the tab.
     */
    icon?: string | SVG;
};
type TabIconProps = {
    /**
     * Tab label.
     */
    label?: string;
    /**
     * Material Symbol name or SVG element used as the icon that will be displayed in the tab.
     */
    icon: string | SVG;
};
type TabProps = {
    defaultActive?: boolean;
    active?: boolean;
    title?: string;
    tabId?: string;
    disabled?: boolean;
    notificationNumber?: boolean | number;
    children: ReactNode;
    onClick?: () => void;
    onHover?: () => void;
} & (TabLabelProps | TabIconProps);
type LegacyProps = {
    /**
     * Initially active tab, only when it is uncontrolled.
     */
    defaultActiveTabIndex?: number;
    /**
     * The index of the active tab. If undefined, the component will be
     * uncontrolled and the active tab will be managed internally by the component.
     */
    activeTabIndex?: number;
    /**
     * An array of objects representing the tabs.
     */
    tabs?: (TabCommonProps & (TabLabelProps | TabIconProps))[];
    /**
     * Whether the icon should appear above or to the left of the label.
     */
    iconPosition?: "top" | "left";
    /**
     * This function will be called when the user clicks on a tab. The index of the
     * clicked tab will be passed as a parameter.
     */
    onTabClick?: (index: number) => void;
    /**
     * This function will be called when the user hovers a tab.The index of the
     * hovered tab will be passed as a parameter.
     */
    onTabHover?: (index: number | null) => void;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Value of the tabindex attribute applied to each tab.
     */
    tabIndex?: number;
};
type NewProps = {
    /**
     * Whether the icon should appear above or to the left of the label.
     */
    iconPosition?: "top" | "left";
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Value of the tabindex attribute applied to each tab.
     */
    tabIndex?: number;
    /**
     * Contains one or more DxcTabs.Tab.
     */
    children?: ReactNode;
};
type Props$7 = LegacyProps & NewProps;

declare const DxcTabs: {
    ({ defaultActiveTabIndex, activeTabIndex, tabs, onTabClick, onTabHover, margin, iconPosition, tabIndex, children, }: Props$7): false | react_jsx_runtime.JSX.Element;
    Tab: react.ForwardRefExoticComponent<TabProps & react.RefAttributes<HTMLButtonElement>>;
};

type TagCommonProps = {
    /**
     * If defined, the tag will be displayed as an anchor, using this prop as "href".
     * Component will show some visual feedback on hover.
     */
    linkHref?: string;
    /**
     * If defined, the tag will be displayed as a button. This function will
     * be called when the user clicks the tag. Component will show some
     * visual feedback on hover.
     */
    onClick?: () => void;
    /**
     * Background color of the icon section of the tag.
     */
    iconBgColor?: string;
    /**
     * Whether the label should appear after or before the icon.
     */
    labelPosition?: "before" | "after";
    /**
     * If true, the page is opened in a new browser tab.
     */
    newWindow?: boolean;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent" | "fitContent";
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
};
type TagLabelProps = TagCommonProps & {
    /**
     * Material Symbol name or SVG element used as the icon that will be placed next to the label.
     */
    icon?: string | SVG;
    /**
     * Text to be placed next inside the tag.
     */
    label: string;
};
type TagIconProps = TagCommonProps & {
    /**
     * Material Symbol name or SVG element used as the icon that will be placed next to the label.
     */
    icon: string | SVG;
    /**
     * Text to be placed next inside the tag.
     */
    label?: string;
};
type Props$6 = TagLabelProps | TagIconProps;

/**
 * @deprecated
 */
declare const DxcTag: ({ icon, label, linkHref, onClick, iconBgColor, labelPosition, newWindow, margin, size, tabIndex, }: Props$6) => JSX.Element;

type Props$5 = {
    /**
     * Text to be placed above the textarea.
     */
    label?: string;
    /**
     * Name attribute of the textarea element.
     */
    name?: string;
    /**
     * Initial value of the textarea, only when it is uncontrolled.
     */
    defaultValue?: string;
    /**
     * Value of the textarea. If undefined, the component will be uncontrolled and the value will be managed internally.
     */
    value?: string;
    /**
     * Helper text to be placed above the textarea.
     */
    helperText?: string;
    /**
     * Text to be put as placeholder of the textarea.
     */
    placeholder?: string;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * If true, the component will not be mutable, meaning the user can not edit the control.
     */
    readOnly?: boolean;
    /**
     * If true, the textarea will be optional, showing '(Optional)'
     * next to the label. Otherwise, the field will be considered required
     * and an error will be passed as a parameter to the OnBlur and onChange functions
     * when it has not been filled.
     */
    optional?: boolean;
    /**
     * Defines the textarea's ability to resize vertically. It can be:
     *    - 'auto': The textarea grows or shrinks automatically in order to fit the content.
     *    - 'manual': The height of the textarea is enabled to be manually modified.
     *    - 'none': The textarea has a fixed height and can't be modified.
     */
    verticalGrow?: "auto" | "manual" | "none";
    /**
     * Number of rows of the textarea.
     */
    rows?: number;
    /**
     * This function will be called when the user types within the textarea.
     * An object including the current value and the error (if the value
     * entered is not valid) will be passed to this function.
     * If there is no error, error will not be defined.
     */
    onChange?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * This function will be called when the textarea loses the focus. An
     * object including the textarea value and the error (if the value entered
     * is not valid) will be passed to this function. If there is no error,
     * error will not be defined.
     */
    onBlur?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * If it is a defined value and also a truthy string, the component will
     * change its appearance, showing the error below the textarea. If the
     * defined value is an empty string, it will reserve a space below the
     * component for a future error, but it would not change its look. In
     * case of being undefined or null, both the appearance and the space for
     * the error message would not be modified.
     */
    error?: string;
    /**
     * Regular expression that defines the valid format allowed by the
     * textarea. This will be checked both when the textarea loses the focus
     * and while typing within it. If the string entered does not match the
     * pattern, the onBlur and onChange functions will be called with the
     * current value and an internal error informing that this value does not
     * match the pattern. If the pattern is met, the error parameter of both
     * events will not be defined.
     */
    pattern?: string;
    /**
     * Specifies the minimum length allowed by the textarea.
     * This will be checked both when the textarea loses the
     * focus and while typing within it. If the string entered does not
     * comply the minimum length, the onBlur and onChange functions will be called
     * with the current value and an internal error informing that the value
     * length does not comply the specified range. If a valid length is
     * reached, the error parameter of both events will not be defined.
     */
    minLength?: number;
    /**
     * Specifies the maximum length allowed by the textarea.
     * This will be checked both when the textarea loses the
     * focus and while typing within it. If the string entered does not
     * comply the maximum length, the onBlur and onChange functions will be called
     * with the current value and an internal error informing that the value
     * length does not comply the specified range. If a valid length is
     * reached, the error parameter of both events will not be defined.
     */
    maxLength?: number;
    /**
     * HTML autocomplete attribute. Lets the user specify if any permission the user agent has to provide automated assistance in filling out the textarea value.
     * Its value must be one of all the possible values of the HTML autocomplete attribute: 'on', 'off', 'email', 'username', 'new-password', ...
     */
    autocomplete?: string;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent";
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the textarea element when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcTextarea: react.ForwardRefExoticComponent<Props$5 & react.RefAttributes<HTMLDivElement>>;

type Action$1 = {
    /**
     * This function will be called when the user clicks the action.
     */
    onClick: () => void;
    /**
     * Icon to be placed in the action..
     */
    icon: string | SVG;
    /**
     * Text representing advisory information related
     * to the button's action. Under the hood, this prop also serves
     * as an accessible label for the component.
     */
    title?: string;
};
type Props$4 = {
    /**
     * Text to be placed above the input. This label will be used as the aria-label attribute of the list of suggestions.
     */
    label?: string;
    /**
     * Name attribute of the input element.
     */
    name?: string;
    /**
     * Initial value of the input, only when it is uncontrolled.
     */
    defaultValue?: string;
    /**
     * Value of the input. If undefined, the component will be uncontrolled and the value will be managed internally by the component.
     */
    value?: string;
    /**
     * Helper text to be placed above the input.
     */
    helperText?: string;
    /**
     * Text to be put as placeholder of the input.
     */
    placeholder?: string;
    /**
     * Action to be shown in the input.
     */
    action?: Action$1;
    /**
     * If true, the input will have an action to clear the entered value.
     */
    clearable?: boolean;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * If true, the component will not be mutable, meaning the user can not edit the control.
     * In addition, the clear action will not be displayed even if the flag is set to true
     * and the custom action will not execute its onClick event.
     */
    readOnly?: boolean;
    /**
     * If true, the input will be optional, showing '(Optional)'
     * next to the label. Otherwise, the field will be considered required and an error will be
     * passed as a parameter to the OnBlur and onChange functions when it has
     * not been filled.
     */
    optional?: boolean;
    /**
     * Prefix to be placed before the input value.
     */
    prefix?: string;
    /**
     * Suffix to be placed after the input value.
     */
    suffix?: string;
    /**
     * This function will be called when the user types within the input
     * element of the component. An object including the current value and
     * the error (if the value entered is not valid) will be passed to this
     * function. If there is no error, error will not be defined.
     */
    onChange?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * This function will be called when the input element loses the focus.
     * An object including the input value and the error (if the value
     * entered is not valid) will be passed to this function. If there is no error,
     * error will not be defined.
     */
    onBlur?: (val: {
        value: string;
        error?: string;
    }) => void;
    /**
     * If it is a defined value and also a truthy string, the component will
     * change its appearance, showing the error below the input component. If
     * the defined value is an empty string, it will reserve a space below
     * the component for a future error, but it would not change its look. In
     * case of being undefined or null, both the appearance and the space for
     * the error message would not be modified.
     */
    error?: string;
    /**
     * These are the options to be displayed as suggestions. It can be either an array or a function:
     *    - Array:    Array of options that will be filtered by the component.
     *    - Function: This function will be called when the user changes the value.
     *                It will receive the new value as a parameter and should return a promise
     *                that resolves to an array with the filtered options.
     */
    suggestions?: string[] | ((value: string) => Promise<string[]>);
    /**
     * Regular expression that defines the valid format allowed by the input.
     * This will be checked both when the input element loses the focus and
     * while typing within it. If the string entered does not match the
     * pattern, the onBlur and onChange functions will be called with the
     * current value and an internal error informing that this value does not
     * match the pattern. If the pattern is met, the error parameter of both
     * events will not be defined.
     */
    pattern?: string;
    /**
     * Specifies the minimum length allowed by the input.
     * This will be checked both when the input element loses the
     * focus and while typing within it. If the string entered does not
     * comply the minimum length, the onBlur and onChange functions will be called
     * with the current value and an internal error informing that the value
     * length does not comply the specified range. If a valid length is
     * reached, the error parameter of both events will not be defined.
     */
    minLength?: number;
    /**
     * Specifies the maximum length allowed by the input.
     * This will be checked both when the input element loses the
     * focus and while typing within it. If the string entered does not
     * comply the maximum length, the onBlur and onChange functions will be called
     * with the current value and an internal error informing that the value
     * length does not comply the specified range. If a valid length is
     * reached, the error parameter of both events will not be defined.
     */
    maxLength?: number;
    /**
     * HTML autocomplete attribute. Lets the user specify if any permission the user agent has to provide automated assistance in filling out the input value.
     * Its value must be one of all the possible values of the HTML autocomplete attribute: 'on', 'off', 'email', 'username', 'new-password', ...
     */
    autocomplete?: string;
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Size of the component.
     */
    size?: "small" | "medium" | "large" | "fillParent";
    /**
     * Value of the tabindex attribute.
     */
    tabIndex?: number;
    /**
     * Specifies a string to be used as the name for the textInput element when no `label` is provided.
     */
    ariaLabel?: string;
};

declare const DxcTextInput: react.ForwardRefExoticComponent<Props$4 & react.RefAttributes<HTMLDivElement>>;

type Action = {
    /**
     * The icon of the action. It can be a string with the name of the icon or an SVG component.
     */
    icon?: string | SVG;
    /**
     * The label of the action.
     */
    label: string;
    /**
     * The function that will be executed when the user clicks on the action button.
     */
    onClick: () => void;
};
type CommonProps$1 = {
    /**
     * Tertiary button which performs a custom action, specified by the user.
     */
    action?: Action;
    /**
     * Message to be displayed as a toast.
     */
    message: string;
};
type DefaultToast = CommonProps$1 & {
    /**
     * Material Symbol name or SVG element as the icon that will be placed next to the panel label.
     * When using Material Symbols, replace spaces with underscores.
     * By default they are outlined if you want it to be filled prefix the symbol name with "filled_".
     */
    icon?: string | SVG;
};
type LoadingToast = CommonProps$1 & {
    loading: boolean;
};
type SemanticToast = CommonProps$1 & {
    /**
     * Flag that allows to hide the semantic icon of the toast.
     */
    hideSemanticIcon?: boolean;
};
type ToastsQueuePropsType = {
    /**
     * Duration in milliseconds before a toast automatically hides itself.
     * The range goes from 3000ms to 5000ms, any other value will not be taken into consideration.
     */
    duration?: number;
    /**
     * Tree of components from which the useToast hook can be triggered.
     */
    children: ReactNode;
};

declare const DxcToastsQueue: ({ children, duration }: ToastsQueuePropsType) => react_jsx_runtime.JSX.Element;

type OptionIcon = {
    /**
     * String with the option display value.
     */
    label?: never;
    /**
     * Material Symbols icon or SVG element. Icon and label can't be used at same time.
     */
    icon: string | SVG;
    /**
     * Value for the HTML properties title and aria-label.
     * When a label is defined, this prop can not be use.
     */
    title: string;
};
type OptionLabel = {
    /**
     * String with the option display value.
     */
    label: string;
    /**
     * Material Symbols icon or SVG element. Icon and label can't be used at same time.
     */
    icon?: string | SVG;
    /**
     * Value for the HTML properties title and aria-label.
     * When a label is defined, this prop can not be use.
     */
    title?: never;
};
type Option = {
    /**
     * Number with the option inner value.
     */
    value: number;
} & (OptionIcon | OptionLabel);
type CommonProps = {
    /**
     * Text to be placed above the component.
     */
    label?: string;
    /**
     * Helper text to be placed above the component.
     */
    helperText?: string;
    /**
     * If true, the component will be disabled.
     */
    disabled?: boolean;
    /**
     * An array of objects representing the selectable options.
     */
    options: Option[];
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Value of the tabindex.
     */
    tabIndex?: number;
};
type SingleSelectionToggleGroup = CommonProps & {
    /**
     * If true, the toggle group will support multiple selection. In that case, value must be an array of numbers with the keys of the selected values.
     */
    multiple?: false;
    /**
     * The key of the initially selected value.
     */
    defaultValue?: number;
    /**
     * The key of the selected value. If the component allows multiple selection, value must be an array.
     * If undefined, the component will be uncontrolled and the value will be managed internally by the component.
     */
    value?: number;
    /**
     * This function will be called every time the selection changes. The number with the key of the selected
     * value will be passed as a parameter to this function.
     */
    onChange?: (optionIndex: number) => void;
};
type MultipleSelectionToggleGroup = CommonProps & {
    /**
     * If true, the toggle group will support multiple selection. In that case, value must be an array of numbers with the keys of the selected values.
     */
    multiple: true;
    /**
     * The array of keys with the initially selected values.
     */
    defaultValue?: number[];
    /**
     * An array with the keys of the selected values.
     * If undefined, the component will be uncontrolled and the value will be managed internally by the component.
     */
    value?: number[];
    /**
     * This function will be called every time the selection changes. An array with the key of
     * the selected values will be passed as a parameter to this function.
     */
    onChange?: (optionIndex: number[]) => void;
};
type Props$3 = SingleSelectionToggleGroup | MultipleSelectionToggleGroup;

declare const DxcToggleGroup: ({ label, helperText, defaultValue, value, onChange, disabled, options, margin, multiple, tabIndex, }: Props$3) => JSX.Element;

type Props$2 = {
    /**
     * Preferred position for displaying the tooltip. It may adjust automatically based on available space.
     */
    position?: "bottom" | "top" | "left" | "right";
    /**
     * Text to be displayed inside the tooltip.
     */
    label?: string;
    /**
     * Content in which the Tooltip will be displayed.
     */
    children: ReactNode;
};

declare function DxcTooltip(props: Props$2): react_jsx_runtime.JSX.Element;

type Props$1 = {
    as?: "a" | "blockquote" | "cite" | "code" | "div" | "em" | "figcaption" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "p" | "pre" | "small" | "span" | "strong";
    children: ReactNode;
    color?: string;
    display?: "inline" | "block";
    fontFamily?: "Open Sans, sans-serif" | "Source Code Pro, monospace";
    fontSize?: "0.75rem" | "0.875rem" | "1rem" | "1.25rem" | "1.5rem" | "2rem" | "3rem" | "3.75rem";
    fontStyle?: "italic" | "normal";
    fontWeight?: "300" | "400" | "600" | "700";
    letterSpacing?: "-0.025em" | "-0.0125em" | "0em" | "0.025em" | "0.05em" | "0.1em";
    lineHeight?: "1em" | "1.25em" | "1.365em" | "1.5em" | "1.715em" | "2em";
    textAlign?: "left" | "center" | "right";
    textDecoration?: "none" | "underline" | "line-through";
    textOverflow?: "clip" | "ellipsis" | "unset";
    whiteSpace?: "normal" | "nowrap" | "pre" | "pre-line" | "pre-wrap";
};

declare function DxcTypography({ children, ...props }: Props$1): react_jsx_runtime.JSX.Element;

type StepProps = {
    /**
     * Step label.
     */
    label: string;
    /**
     * Description that will be placed next to the step.
     */
    description?: string;
    /**
     * Material Symbol name or SVG element used as the icon displayed in the step.
     */
    icon?: string | SVG;
    /**
     * Whether the step is disabled or not.
     */
    disabled?: boolean;
    /**
     * Whether the step is valid or not.
     */
    valid?: boolean;
};
type Props = {
    /**
     * The wizard can be shown in horizontal or vertical.
     */
    mode?: "horizontal" | "vertical";
    /**
     * Initially selected step, only when it is uncontrolled.
     */
    defaultCurrentStep?: number;
    /**
     * Defines which step is marked as the current. The numeration starts at 0.
     */
    currentStep?: number;
    /**
     * This function will be called when the user clicks a step. The step
     * number will be passed as a parameter.
     */
    onStepClick?: (currentStep: number) => void;
    /**
     * An array of objects representing the steps.
     */
    steps: StepProps[];
    /**
     * Size of the margin to be applied to the component ('xxsmall' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge').
     * You can pass an object with 'top', 'bottom', 'left' and 'right' properties in order to specify different margin sizes.
     */
    margin?: Space$1 | Margin;
    /**
     * Value of the tabindex attribute that is given to all the steps.
     */
    tabIndex?: number;
};

declare const DxcWizard: ({ mode, defaultCurrentStep, currentStep, onStepClick, steps, margin, tabIndex, }: Props) => JSX.Element;

declare const componentTokens: {
    accordion: {
        backgroundColor: string;
        hoverBackgroundColor: string;
        focusBackgroundColor: string;
        activeBackgroundColor: string;
        arrowColor: string;
        disabledArrowColor: string;
        subLabelFontFamily: string;
        subLabelFontSize: string;
        subLabelFontWeight: string;
        subLabelFontStyle: string;
        subLabelFontColor: string;
        disabledSubLabelFontColor: string;
        assistiveTextFontFamily: string;
        assistiveTextFontSize: string;
        assistiveTextFontWeight: string;
        assistiveTextFontStyle: string;
        assistiveTextFontColor: string;
        disabledAssistiveTextFontColor: string;
        titleLabelFontFamily: string;
        titleLabelFontSize: string;
        titleLabelFontWeight: string;
        titleLabelFontStyle: string;
        titleLabelFontColor: string;
        disabledTitleLabelFontColor: string;
        focusBorderColor: string;
        focusBorderStyle: string;
        focusBorderThickness: string;
        borderRadius: string;
        boxShadowOffsetX: string;
        boxShadowOffsetY: string;
        boxShadowBlur: string;
        boxShadowSpread: string;
        boxShadowColor: string;
        iconColor: string;
        disabledIconColor: string;
        iconSize: string;
        accordionSeparatorBorderColor: string;
        accordionSeparatorBorderThickness: string;
        accordionSeparatorBorderStyle: string;
    };
    alert: {
        errorBackgroundColor: string;
        errorIconColor: string;
        fontColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        iconSize: string;
        infoBackgroundColor: string;
        infoIconColor: string;
        modalBackgroundColor: string;
        modalTitleFontSize: string;
        modalTitleFontWeight: string;
        overlayColor: string;
        successBackgroundColor: string;
        successIconColor: string;
        warningBackgroundColor: string;
        warningIconColor: string;
    };
    bulletedList: {
        fontColor: string;
        bulletIconHeight: string;
        bulletIconWidth: string;
        bulletHeight: string;
        bulletWidth: string;
        bulletMarginRight: string;
    };
    button: {
        labelFontLineHeight: string;
        labelLetterSpacing: string;
        paddingSmallTop: string;
        paddingSmallLeft: string;
        paddingSmallBottom: string;
        paddingSmallRight: string;
        paddingSmallOnlyIconTop: string;
        paddingSmallOnlyIconLeft: string;
        paddingSmallOnlyIconBottom: string;
        paddingSmallOnlyIconRight: string;
        paddingMediumTop: string;
        paddingMediumLeft: string;
        paddingMediumBottom: string;
        paddingMediumRight: string;
        paddingMediumOnlyIconTop: string;
        paddingMediumOnlyIconLeft: string;
        paddingMediumOnlyIconBottom: string;
        paddingMediumOnlyIconRight: string;
        paddingLargeTop: string;
        paddingLargeLeft: string;
        paddingLargeBottom: string;
        paddingLargeRight: string;
        paddingLargeOnlyIconTop: string;
        paddingLargeOnlyIconLeft: string;
        paddingLargeOnlyIconBottom: string;
        paddingLargeOnlyIconRight: string;
        focusBorderColor: string;
        primaryDefaultBackgroundColor: string;
        primaryErrorBackgroundColor: string;
        primaryWarningBackgroundColor: string;
        primarySuccessBackgroundColor: string;
        primaryInfoBackgroundColor: string;
        primaryDefaultFontColor: string;
        primaryErrorFontColor: string;
        primaryWarningFontColor: string;
        primarySuccessFontColor: string;
        primaryInfoFontColor: string;
        primaryHoverDefaultBackgroundColor: string;
        primaryHoverErrorBackgroundColor: string;
        primaryHoverWarningBackgroundColor: string;
        primaryHoverSuccessBackgroundColor: string;
        primaryHoverInfoBackgroundColor: string;
        primaryActiveDefaultBackgroundColor: string;
        primaryActiveErrorBackgroundColor: string;
        primaryActiveWarningBackgroundColor: string;
        primaryActiveSuccessBackgroundColor: string;
        primaryActiveInfoBackgroundColor: string;
        primaryDisabledDefaultBackgroundColor: string;
        primaryDisabledErrorBackgroundColor: string;
        primaryDisabledWarningBackgroundColor: string;
        primaryDisabledSuccessBackgroundColor: string;
        primaryDisabledInfoBackgroundColor: string;
        primaryDisabledDefaultFontColor: string;
        primaryDisabledErrorFontColor: string;
        primaryDisabledWarningFontColor: string;
        primaryDisabledSuccessFontColor: string;
        primaryDisabledInfoFontColor: string;
        primaryBorderThickness: string;
        primaryBorderStyle: string;
        primaryBorderRadius: string;
        primaryFontFamily: string;
        primarySmallFontSize: string;
        primaryMediumFontSize: string;
        primaryLargeFontSize: string;
        primaryFontWeight: string;
        secondaryDefaultBackgroundColor: string;
        secondaryErrorBackgroundColor: string;
        secondaryWarningBackgroundColor: string;
        secondarySuccessBackgroundColor: string;
        secondaryInfoBackgroundColor: string;
        secondaryDefaultFontColor: string;
        secondaryErrorFontColor: string;
        secondaryWarningFontColor: string;
        secondarySuccessFontColor: string;
        secondaryInfoFontColor: string;
        secondaryDefaultBorderColor: string;
        secondaryErrorBorderColor: string;
        secondaryWarningBorderColor: string;
        secondarySuccessBorderColor: string;
        secondaryInfoBorderColor: string;
        secondaryHoverDefaultBackgroundColor: string;
        secondaryHoverErrorBackgroundColor: string;
        secondaryHoverWarningBackgroundColor: string;
        secondaryHoverSuccessBackgroundColor: string;
        secondaryHoverInfoBackgroundColor: string;
        secondaryHoverDefaultFontColor: string;
        secondaryHoverErrorFontColor: string;
        secondaryHoverWarningFontColor: string;
        secondaryHoverSuccessFontColor: string;
        secondaryHoverInfoFontColor: string;
        secondaryActiveDefaultBackgroundColor: string;
        secondaryActiveErrorBackgroundColor: string;
        secondaryActiveWarningBackgroundColor: string;
        secondaryActiveSuccessBackgroundColor: string;
        secondaryActiveInfoBackgroundColor: string;
        secondaryDisabledDefaultBackgroundColor: string;
        secondaryDisabledErrorBackgroundColor: string;
        secondaryDisabledWarningBackgroundColor: string;
        secondaryDisabledSuccessBackgroundColor: string;
        secondaryDisabledInfoBackgroundColor: string;
        secondaryDisabledDefaultFontColor: string;
        secondaryDisabledErrorFontColor: string;
        secondaryDisabledWarningFontColor: string;
        secondaryDisabledSuccessFontColor: string;
        secondaryDisabledInfoFontColor: string;
        secondaryDisabledDefaultBorderColor: string;
        secondaryDisabledErrorBorderColor: string;
        secondaryDisabledWarningBorderColor: string;
        secondaryDisabledSuccessBorderColor: string;
        secondaryDisabledInfoBorderColor: string;
        secondaryBorderThickness: string;
        secondaryBorderStyle: string;
        secondaryBorderRadius: string;
        secondaryFontFamily: string;
        secondarySmallFontSize: string;
        secondaryMediumFontSize: string;
        secondaryLargeFontSize: string;
        secondaryFontWeight: string;
        tertiaryDefaultBackgroundColor: string;
        tertiaryErrorBackgroundColor: string;
        tertiaryWarningBackgroundColor: string;
        tertiarySuccessBackgroundColor: string;
        tertiaryInfoBackgroundColor: string;
        tertiaryDefaultFontColor: string;
        tertiaryErrorFontColor: string;
        tertiaryWarningFontColor: string;
        tertiarySuccessFontColor: string;
        tertiaryInfoFontColor: string;
        tertiaryHoverDefaultBackgroundColor: string;
        tertiaryHoverErrorBackgroundColor: string;
        tertiaryHoverWarningBackgroundColor: string;
        tertiaryHoverSuccessBackgroundColor: string;
        tertiaryHoverInfoBackgroundColor: string;
        tertiaryActiveDefaultBackgroundColor: string;
        tertiaryActiveErrorBackgroundColor: string;
        tertiaryActiveWarningBackgroundColor: string;
        tertiaryActiveSuccessBackgroundColor: string;
        tertiaryActiveInfoBackgroundColor: string;
        tertiaryDisabledDefaultBackgroundColor: string;
        tertiaryDisabledErrorBackgroundColor: string;
        tertiaryDisabledWarningBackgroundColor: string;
        tertiaryDisabledSuccessBackgroundColor: string;
        tertiaryDisabledInfoBackgroundColor: string;
        tertiaryDisabledDefaultFontColor: string;
        tertiaryDisabledErrorFontColor: string;
        tertiaryDisabledWarningFontColor: string;
        tertiaryDisabledSuccessFontColor: string;
        tertiaryDisabledInfoFontColor: string;
        tertiaryBorderThickness: string;
        tertiaryBorderStyle: string;
        tertiaryBorderRadius: string;
        tertiaryFontFamily: string;
        tertiarySmallFontSize: string;
        tertiaryMediumFontSize: string;
        tertiaryLargeFontSize: string;
        tertiaryFontWeight: string;
    };
    card: {
        height: string;
        width: string;
    };
    checkbox: {
        backgroundColorChecked: string;
        hoverBackgroundColorChecked: string;
        disabledBackgroundColorChecked: string;
        readOnlyBackgroundColorChecked: string;
        hoverReadOnlyBackgroundColorChecked: string;
        borderColor: string;
        hoverBorderColor: string;
        disabledBorderColor: string;
        readOnlyBorderColor: string;
        hoverReadOnlyBorderColor: string;
        checkColor: string;
        disabledCheckColor: string;
        readOnlyCheckColor: string;
        fontFamily: string;
        fontSize: string;
        fontWeight: string;
        fontColor: string;
        disabledFontColor: string;
        focusColor: string;
        checkLabelSpacing: string;
    };
    chip: {
        backgroundColor: string;
        disabledBackgroundColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        fontColor: string;
        disabledFontColor: string;
        borderColor: string;
        borderRadius: string;
        borderThickness: string;
        borderStyle: string;
        contentPaddingLeft: string;
        contentPaddingRight: string;
        contentPaddingTop: string;
        contentPaddingBottom: string;
        iconSize: string;
        iconSpacing: string;
        iconColor: string;
        hoverIconColor: string;
        activeIconColor: string;
        disabledIconColor: string;
        focusColor: string;
        focusBorderStyle: string;
        focusBorderThickness: string;
        focusBorderRadius: string;
    };
    contextualMenu: {
        fontFamily: string;
        backgroundColor: string;
        borderColor: string;
        menuItemFontColor: string;
        menuItemFontSize: string;
        menuItemFontStyle: string;
        menuItemFontWeight: string;
        menuItemLineHeight: string;
        hoverMenuItemBackgroundColor: string;
        activeMenuItemBackgroundColor: string;
        selectedMenuItemBackgroundColor: string;
        hoverSelectedMenuItemBackgroundColor: string;
        activeSelectedMenuItemBackgroundColor: string;
        selectedMenuItemFontWeight: string;
        sectionTitleFontColor: string;
        sectionTitleFontSize: string;
        sectionTitleFontStyle: string;
        sectionTitleFontWeight: string;
        sectionTitleLineHeight: string;
        iconColor: string;
        iconSize: string;
    };
    dataGrid: {
        rowSeparatorThickness: string;
        rowSeparatorStyle: string;
        rowSeparatorColor: string;
        dataBackgroundColor: string;
        dataFontFamily: string;
        dataFontSize: string;
        dataFontStyle: string;
        dataFontWeight: string;
        dataFontColor: string;
        dataFontTextTransform: string;
        dataPaddingRight: string;
        dataPaddingLeft: string;
        dataRowHeight: number;
        dataTextLineHeight: string;
        headerBackgroundColor: string;
        headerBorderRadius: string;
        headerFontFamily: string;
        headerFontSize: string;
        headerFontStyle: string;
        headerFontWeight: string;
        headerFontColor: string;
        headerFontTextTransform: string;
        headerPaddingRight: string;
        headerPaddingLeft: string;
        headerRowHeight: number;
        headerTextLineHeight: string;
        headerCheckboxBackgroundColorChecked: string;
        headerCheckboxHoverBackgroundColorChecked: string;
        headerCheckboxBorderColor: string;
        headerCheckboxHoverBorderColor: string;
        headerCheckboxCheckColor: string;
        summaryRowHeight: number;
        focusColor: string;
        scrollBarThumbColor: string;
        scrollBarTrackColor: string;
        actionIconColor: string;
        disabledActionIconColor: string;
        hoverActionIconColor: string;
        focusActionIconColor: string;
        activeActionIconColor: string;
        actionBackgroundColor: string;
        disabledActionBackgroundColor: string;
        hoverActionBackgroundColor: string;
        focusActionBorderColor: string;
        activeActionBackgroundColor: string;
    };
    dateInput: {
        pickerBackgroundColor: string;
        pickerFontColor: string;
        pickerBorderColor: string;
        pickerSelectedBackgroundColor: string;
        pickerSelectedFontColor: string;
        pickerHoverBackgroundColor: string;
        pickerHoverFontColor: string;
        pickerActiveBackgroundColor: string;
        pickerActiveFontColor: string;
        pickerNonCurrentMonthFontColor: string;
        pickerCurrentDateBorderColor: string;
        pickerCurrentDateFontColor: string;
        pickerCurrentYearFontColor: string;
        pickerHeaderBackgroundColor: string;
        pickerHeaderFontColor: string;
        pickerHeaderHoverBackgroundColor: string;
        pickerHeaderHoverFontColor: string;
        pickerHeaderActiveBackgroundColor: string;
        pickerHeaderActiveFontColor: string;
        pickerFocusColor: string;
        pickerBorderWidth: string;
        pickerBorderStyle: string;
        pickerFocusWidth: string;
        pickerCurrentDateBorderWidth: string;
        pickerFontFamily: string;
        pickerFontSize: string;
        pickerFontWeight: string;
        pickerInteractedYearFontSize: string;
        pickerHeaderFontSize: string;
    };
    dialog: {
        overlayColor: string;
        backgroundColor: string;
        closeIconBackgroundColor: string;
        closeIconColor: string;
        boxShadowOffsetX: string;
        boxShadowOffsetY: string;
        boxShadowBlur: string;
        boxShadowColor: string;
    };
    dropdown: {
        buttonBackgroundColor: string;
        hoverButtonBackgroundColor: string;
        activeButtonBackgroundColor: string;
        buttonFontFamily: string;
        buttonFontSize: string;
        buttonFontStyle: string;
        buttonFontWeight: string;
        buttonFontColor: string;
        buttonIconSize: string;
        buttonIconSpacing: string;
        buttonIconColor: string;
        buttonPaddingTop: string;
        buttonPaddingBottom: string;
        buttonPaddingLeft: string;
        buttonPaddingRight: string;
        buttonHeight: string;
        buttonBorderRadius: string;
        buttonBorderStyle: string;
        buttonBorderThickness: string;
        buttonBorderColor: string;
        disabledColor: string;
        disabledButtonBackgroundColor: string;
        disabledButtonBorderColor: string;
        optionBackgroundColor: string;
        hoverOptionBackgroundColor: string;
        activeOptionBackgroundColor: string;
        optionFontFamily: string;
        optionFontSize: string;
        optionFontStyle: string;
        optionFontWeight: string;
        optionFontColor: string;
        optionIconSize: string;
        optionIconSpacing: string;
        optionIconColor: string;
        optionPaddingTop: string;
        optionPaddingBottom: string;
        optionPaddingLeft: string;
        optionPaddingRight: string;
        caretIconSize: string;
        caretIconColor: string;
        caretIconSpacing: string;
        borderRadius: string;
        borderStyle: string;
        borderThickness: string;
        borderColor: string;
        scrollBarThumbColor: string;
        scrollBarTrackColor: string;
        focusColor: string;
    };
    fileInput: {
        dropBorderColor: string;
        fileItemBorderColor: string;
        fileNameFontColor: string;
        labelFontColor: string;
        helperTextFontColor: string;
        dropLabelFontColor: string;
        disabledLabelFontColor: string;
        disabledHelperTextFontColor: string;
        disabledDropLabelFontColor: string;
        focusDropBorderColor: string;
        disabledDropBorderColor: string;
        dragoverDropBackgroundColor: string;
        errorFileItemBorderColor: string;
        errorFileItemBackgroundColor: string;
        errorFilePreviewBackgroundColor: string;
        errorFileItemIconColor: string;
        fileItemIconBackgroundColor: string;
        deleteFileItemColor: string;
        errorMessageFontColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontWeight: string;
        labelLineHeight: string;
        fileItemFontFamily: string;
        fileItemFontSize: string;
        fileItemFontWeight: string;
        fileItemLineHeight: string;
        helperTextFontFamily: string;
        helperTextFontSize: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        dropLabelFontFamily: string;
        dropLabelFontSize: string;
        dropLabelFontWeight: string;
        errorMessageFontFamily: string;
        errorMessageFontSize: string;
        errorMessageFontWeight: string;
        errorMessageLineHeight: string;
        dropBorderThickness: string;
        dropBorderStyle: string;
        dropBorderRadius: string;
        fileItemBorderThickness: string;
        fileItemBorderStyle: string;
        fileItemBorderRadius: string;
        hoverDeleteFileItemBackgroundColor: string;
        activeDeleteFileItemBackgroundColor: string;
        focusDeleteFileItemBorderColor: string;
        filePreviewBackgroundColor: string;
        filePreviewIconColor: string;
        errorFilePreviewIconColor: string;
    };
    footer: {
        height: string;
        backgroundColor: string;
        bottomLinksDividerColor: string;
        bottomLinksDividerThickness: string;
        bottomLinksDividerStyle: string;
        bottomLinksDividerSpacing: string;
        bottomLinksFontFamily: string;
        bottomLinksFontSize: string;
        bottomLinksFontStyle: string;
        bottomLinksFontWeight: string;
        bottomLinksFontColor: string;
        bottomLinksTextDecoration: string;
        copyrightFontFamily: string;
        copyrightFontSize: string;
        copyrightFontStyle: string;
        copyrightFontWeight: string;
        copyrightFontColor: string;
        logo: string;
        logoHeight: string;
        logoWidth: string;
        socialLinksSize: string;
        socialLinksGutter: string;
        socialLinksColor: string;
    };
    header: {
        backgroundColor: string;
        hamburgerFocusColor: string;
        hamburgerFontFamily: string;
        hamburgerFontStyle: string;
        hamburgerFontColor: string;
        hamburgerFontSize: string;
        hamburgerFontWeight: string;
        hamburgerTextTransform: string;
        hamburgerIconColor: string;
        hamburgerHoverColor: string;
        logo: string;
        logoResponsive: string;
        logoHeight: string;
        logoWidth: string;
        menuBackgroundColor: string;
        menuZindex: string;
        menuTabletWidth: string;
        menuMobileWidth: string;
        minHeight: string;
        overlayColor: string;
        overlayOpacity: string;
        overlayZindex: string;
        paddingTop: string;
        paddingBottom: string;
        paddingRight: string;
        paddingLeft: string;
        underlinedColor: string;
        underlinedThickness: string;
        underlinedStyle: string;
        contentColor: string;
    };
    heading: {
        level1FontColor: string;
        level1FontFamily: string;
        level1FontSize: string;
        level1FontStyle: string;
        level1FontWeight: string;
        level1LineHeight: string;
        level1LetterSpacing: string;
        level2FontColor: string;
        level2FontFamily: string;
        level2FontSize: string;
        level2FontStyle: string;
        level2FontWeight: string;
        level2LineHeight: string;
        level2LetterSpacing: string;
        level3FontColor: string;
        level3FontFamily: string;
        level3FontSize: string;
        level3FontStyle: string;
        level3FontWeight: string;
        level3LineHeight: string;
        level3LetterSpacing: string;
        level4FontColor: string;
        level4FontFamily: string;
        level4FontSize: string;
        level4FontStyle: string;
        level4FontWeight: string;
        level4LineHeight: string;
        level4LetterSpacing: string;
        level5FontColor: string;
        level5FontFamily: string;
        level5FontSize: string;
        level5FontStyle: string;
        level5FontWeight: string;
        level5LineHeight: string;
        level5LetterSpacing: string;
    };
    image: {
        captionFontColor: string;
        captionFontFamily: string;
        captionFontSize: string;
        captionFontStyle: string;
        captionFontWeight: string;
        captionLineHeight: string;
    };
    link: {
        fontColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        iconSize: string;
        iconSpacing: string;
        underlineSpacing: string;
        underlineStyle: string;
        underlineThickness: string;
        disabledFontColor: string;
        hoverFontColor: string;
        hoverUnderlineColor: string;
        visitedFontColor: string;
        visitedUnderlineColor: string;
        activeFontColor: string;
        activeUnderlineColor: string;
        focusColor: string;
    };
    navTabs: {
        selectedBackgroundColor: string;
        unselectedBackgroundColor: string;
        hoverBackgroundColor: string;
        pressedBackgroundColor: string;
        selectedFontColor: string;
        unselectedFontColor: string;
        disabledFontColor: string;
        focusOutline: string;
        selectedUnderlineColor: string;
        dividerColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        selectedIconColor: string;
        unselectedIconColor: string;
        disabledIconColor: string;
    };
    paginator: {
        backgroundColor: string;
        fontColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        fontTextTransform: string;
        verticalPadding: string;
        horizontalPadding: string;
        marginRight: string;
        marginLeft: string;
        itemsPerPageSelectorMarginLeft: string;
        itemsPerPageSelectorMarginRight: string;
        pageSelectorMarginRight: string;
        pageSelectorMarginLeft: string;
        totalItemsContainerMarginRight: string;
        totalItemsContainerMarginLeft: string;
    };
    paragraph: {
        display: string;
        fontColor: string;
        fontSize: string;
        fontWeight: string;
    };
    progressBar: {
        trackLineColor: string;
        totalLineColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelFontColor: string;
        labelFontTextTransform: string;
        valueFontFamily: string;
        valueFontSize: string;
        valueFontStyle: string;
        valueFontWeight: string;
        valueFontColor: string;
        valueFontTextTransform: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextFontFamily: string;
        thickness: string;
        borderRadius: string;
        overlayColor: string;
        overlayFontColor: string;
    };
    quickNav: {
        fontColor: string;
        hoverFontColor: string;
        dividerBorderColor: string;
        focusBorderColor: string;
        focusBorderStyle: string;
        focusBorderThickness: string;
        focusBorderRadius: string;
        paddingTop: string;
        paddingBottom: string;
        paddingLeft: string;
        paddingRight: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
    };
    radioGroup: {
        fontFamily: string;
        radioInputColor: string;
        hoverRadioInputColor: string;
        focusBorderColor: string;
        activeRadioInputColor: string;
        errorRadioInputColor: string;
        hoverErrorRadioInputColor: string;
        activeErrorRadioInputColor: string;
        readOnlyRadioInputColor: string;
        hoverReadOnlyRadioInputColor: string;
        activeReadOnlyRadioInputColor: string;
        disabledRadioInputColor: string;
        disabledLabelFontColor: string;
        disabledHelperTextFontColor: string;
        disabledRadioInputLabelFontColor: string;
        errorMessageColor: string;
        labelFontColor: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        optionalLabelFontWeight: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        radioInputLabelFontColor: string;
        radioInputLabelFontSize: string;
        radioInputLabelFontStyle: string;
        radioInputLabelFontWeight: string;
        radioInputLabelLineHeight: string;
        groupLabelMargin: string;
        radioInputLabelMargin: string;
        groupVerticalGutter: string;
        groupHorizontalGutter: string;
    };
    select: {
        fontFamily: string;
        disabledColor: string;
        enabledInputBorderColor: string;
        hoverInputBorderColor: string;
        focusInputBorderColor: string;
        errorInputBorderColor: string;
        hoverInputErrorBorderColor: string;
        disabledInputBorderColor: string;
        disabledInputBackgroundColor: string;
        inputMarginTop: string;
        inputMarginBottom: string;
        errorMessageColor: string;
        errorIconColor: string;
        labelFontColor: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        optionalLabelFontWeight: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        placeholderFontColor: string;
        valueFontColor: string;
        valueFontSize: string;
        valueFontStyle: string;
        valueFontWeight: string;
        actionIconColor: string;
        hoverActionIconColor: string;
        activeActionIconColor: string;
        actionBackgroundColor: string;
        hoverActionBackgroundColor: string;
        activeActionBackgroundColor: string;
        listOptionFontColor: string;
        listOptionFontSize: string;
        listOptionFontStyle: string;
        listOptionFontWeight: string;
        listOptionIconColor: string;
        listOptionDividerColor: string;
        listGroupLabelFontWeight: string;
        focusListOptionBorderColor: string;
        systemMessageFontColor: string;
        collapseIndicatorColor: string;
        listDialogBackgroundColor: string;
        listDialogBorderColor: string;
        selectedListOptionBackgroundColor: string;
        selectedHoverListOptionBackgroundColor: string;
        selectedActiveListOptionBackgroundColor: string;
        selectedListOptionIconColor: string;
        unselectedHoverListOptionBackgroundColor: string;
        unselectedActiveListOptionBackgroundColor: string;
        selectionIndicatorFontColor: string;
        selectionIndicatorFontSize: string;
        selectionIndicatorFontStyle: string;
        selectionIndicatorFontWeight: string;
        selectionIndicatorBorderColor: string;
        selectionIndicatorBackgroundColor: string;
        enabledSelectionIndicatorActionBackgroundColor: string;
        enabledSelectionIndicatorActionIconColor: string;
        hoverSelectionIndicatorActionBackgroundColor: string;
        hoverSelectionIndicatorActionIconColor: string;
        activeSelectionIndicatorActionBackgroundColor: string;
        activeSelectionIndicatorActionIconColor: string;
    };
    sidenav: {
        backgroundColor: string;
        titleFontFamily: string;
        titleFontSize: string;
        titleFontStyle: string;
        titleFontWeight: string;
        titleFontColor: string;
        titleFontTextTransform: string;
        titleFontLetterSpacing: string;
        groupTitleFontFamily: string;
        groupTitleFontSize: string;
        groupTitleFontStyle: string;
        groupTitleFontWeight: string;
        groupTitleFontColor: string;
        groupTitleHoverBackgroundColor: string;
        groupTitleActiveBackgroundColor: string;
        groupTitleSelectedFontColor: string;
        groupTitleSelectedBackgroundColor: string;
        groupTitleSelectedHoverFontColor: string;
        groupTitleSelectedHoverBackgroundColor: string;
        groupTitleFontTextTransform: string;
        groupTitleFontLetterSpacing: string;
        linkFontFamily: string;
        linkFontSize: string;
        linkFontStyle: string;
        linkFontWeight: string;
        linkFontColor: string;
        linkHoverBackgroundColor: string;
        linkSelectedFontColor: string;
        linkSelectedBackgroundColor: string;
        linkSelectedHoverFontColor: string;
        linkSelectedHoverBackgroundColor: string;
        linkFontTextTransform: string;
        linkFontLetterSpacing: string;
        linkTextDecoration: string;
        linkMarginTop: string;
        linkMarginBottom: string;
        linkMarginRight: string;
        linkMarginLeft: string;
        linkFocusColor: string;
        scrollBarThumbColor: string;
        scrollBarTrackColor: string;
    };
    slider: {
        fontFamily: string;
        limitValuesFontColor: string;
        limitValuesFontSize: string;
        limitValuesFontStyle: string;
        limitValuesFontWeight: string;
        limitValuesFontLetterSpacing: string;
        disabledLimitValuesFontColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        helperTextFontFamily: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        fontColor: string;
        labelFontColor: string;
        helperTextFontColor: string;
        disabledLabelFontColor: string;
        disabledHelperTextFontColor: string;
        thumbHeight: string;
        thumbWidth: string;
        hoverThumbHeight: string;
        hoverThumbWidth: string;
        thumbVerticalPosition: string;
        hoverThumbVerticalPosition: string;
        thumbBackgroundColor: string;
        hoverThumbScale: string;
        hoverThumbBackgroundColor: string;
        activeThumbScale: string;
        activeThumbBackgroundColor: string;
        focusThumbBackgroundColor: string;
        tickHeight: string;
        tickWidth: string;
        tickVerticalPosition: string;
        tickBackgroundColor: string;
        trackLineThickness: string;
        trackLineVerticalPosition: string;
        trackLineColor: string;
        totalLineThickness: string;
        totalLineVerticalPosition: string;
        totalLineColor: string;
        disabledThumbVerticalPosition: string;
        disabledThumbBackgroundColor: string;
        disabledTickVerticalPosition: string;
        disabledTickBackgroundColor: string;
        disabledTrackLineColor: string;
        disabledTotalLineColor: string;
        focusColor: string;
        floorLabelMarginRight: string;
        ceilLabelMarginLeft: string;
        inputMarginLeft: string;
    };
    spinner: {
        trackCircleColor: string;
        trackCircleColorOverlay: string;
        totalCircleColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelFontColor: string;
        labelTextAlign: string;
        progressValueFontFamily: string;
        progressValueFontSize: string;
        progressValueFontStyle: string;
        progressValueFontWeight: string;
        progressValueFontColor: string;
        progressValueTextAlign: string;
        overlayBackgroundColor: string;
        overlayOpacity: string;
        overlayLabelFontFamily: string;
        overlayLabelFontSize: string;
        overlayLabelFontStyle: string;
        overlayLabelFontWeight: string;
        overlayLabelFontColor: string;
        overlayLabelTextAlign: string;
        overlayProgressValueFontFamily: string;
        overlayProgressValueFontSize: string;
        overlayProgressValueFontStyle: string;
        overlayProgressValueFontWeight: string;
        overlayProgressValueFontColor: string;
        overlayProgressValueTextAlign: string;
    };
    switch: {
        checkedTrackBackgroundColor: string;
        checkedThumbBackgroundColor: string;
        uncheckedTrackBackgroundColor: string;
        uncheckedThumbBackgroundColor: string;
        disabledCheckedTrackBackgroundColor: string;
        disabledCheckedThumbBackgroundColor: string;
        disabledUncheckedTrackBackgroundColor: string;
        disabledUncheckedThumbBackgroundColor: string;
        disabledLabelFontColor: string;
        disabledLabelFontStyle: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelFontColor: string;
        thumbFocusColor: string;
        thumbHeight: string;
        thumbWidth: string;
        thumbShift: string;
        trackHeight: string;
        trackWidth: string;
        spaceBetweenLabelSwitch: string;
    };
    table: {
        rowSeparatorThickness: string;
        rowSeparatorStyle: string;
        rowSeparatorColor: string;
        dataBackgroundColor: string;
        dataFontFamily: string;
        dataFontSize: string;
        dataFontStyle: string;
        dataFontWeight: string;
        dataFontColor: string;
        dataFontTextTransform: string;
        dataPaddingTop: string;
        dataPaddingBottom: string;
        dataPaddingRight: string;
        dataPaddingLeft: string;
        dataPaddingTopReduced: string;
        dataPaddingBottomReduced: string;
        dataPaddingRightReduced: string;
        dataPaddingLeftReduced: string;
        dataTextAlign: string;
        dataTextLineHeight: string;
        firstChildPaddingLeft: string;
        lastChildPaddingRight: string;
        firstChildPaddingLeftReduced: string;
        lastChildPaddingRightReduced: string;
        headerBackgroundColor: string;
        headerBorderRadius: string;
        headerFontFamily: string;
        headerFontSize: string;
        headerFontStyle: string;
        headerFontWeight: string;
        headerFontColor: string;
        headerFontTextTransform: string;
        headerPaddingTop: string;
        headerPaddingBottom: string;
        headerPaddingRight: string;
        headerPaddingLeft: string;
        headerPaddingTopReduced: string;
        headerPaddingBottomReduced: string;
        headerPaddingRightReduced: string;
        headerPaddingLeftReduced: string;
        headerTextAlign: string;
        headerTextLineHeight: string;
        scrollBarThumbColor: string;
        scrollBarTrackColor: string;
        sortIconColor: string;
        actionIconColor: string;
        disabledActionIconColor: string;
        hoverActionIconColor: string;
        focusActionIconColor: string;
        activeActionIconColor: string;
        actionBackgroundColor: string;
        disabledActionBackgroundColor: string;
        hoverActionBackgroundColor: string;
        focusActionBorderColor: string;
        activeActionBackgroundColor: string;
    };
    tabs: {
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        fontTextTransform: string;
        selectedBackgroundColor: string;
        selectedFontColor: string;
        selectedIconColor: string;
        selectedUnderlineColor: string;
        selectedUnderlineThickness: string;
        unselectedBackgroundColor: string;
        unselectedFontColor: string;
        unselectedIconColor: string;
        disabledFontColor: string;
        disabledIconColor: string;
        disabledFontStyle: string;
        hoverBackgroundColor: string;
        pressedBackgroundColor: string;
        pressedFontWeight: string;
        dividerColor: string;
        dividerThickness: string;
        focusOutline: string;
        scrollButtonsWidth: string;
    };
    tag: {
        fontFamily: string;
        fontColor: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        labelPaddingTop: string;
        labelPaddingBottom: string;
        labelPaddingLeft: string;
        labelPaddingRight: string;
        height: string;
        iconColor: string;
        iconSectionWidth: string;
        iconHeight: string;
        iconWidth: string;
        focusColor: string;
    };
    textarea: {
        fontFamily: string;
        enabledBorderColor: string;
        hoverBorderColor: string;
        focusBorderColor: string;
        disabledBorderColor: string;
        disabledContainerFillColor: string;
        readOnlyBorderColor: string;
        hoverReadOnlyBorderColor: string;
        errorBorderColor: string;
        hoverErrorBorderColor: string;
        inputMarginTop: string;
        inputMarginBottom: string;
        errorMessageColor: string;
        labelFontColor: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        disabledLabelFontColor: string;
        optionalLabelFontWeight: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        disabledHelperTextFontColor: string;
        placeholderFontColor: string;
        disabledPlaceholderFontColor: string;
        valueFontColor: string;
        valueFontSize: string;
        valueFontStyle: string;
        valueFontWeight: string;
        disabledValueFontColor: string;
    };
    textInput: {
        fontFamily: string;
        enabledBorderColor: string;
        hoverBorderColor: string;
        focusBorderColor: string;
        disabledBorderColor: string;
        disabledContainerFillColor: string;
        readOnlyBorderColor: string;
        hoverReadOnlyBorderColor: string;
        errorBorderColor: string;
        hoverErrorBorderColor: string;
        inputMarginTop: string;
        inputMarginBottom: string;
        errorMessageColor: string;
        errorIconColor: string;
        labelFontColor: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        disabledLabelFontColor: string;
        optionalLabelFontWeight: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        disabledHelperTextFontColor: string;
        prefixColor: string;
        prefixDividerBorderWidth: string;
        prefixDividerBorderStyle: string;
        prefixDividerPaddingRight: string;
        suffixColor: string;
        suffixDividerBorderStyle: string;
        suffixDividerBorderWidth: string;
        suffixDividerPaddingLeft: string;
        disabledPrefixColor: string;
        disabledSuffixColor: string;
        placeholderFontColor: string;
        disabledPlaceholderFontColor: string;
        valueFontColor: string;
        valueFontSize: string;
        valueFontStyle: string;
        valueFontWeight: string;
        disabledValueFontColor: string;
        actionIconColor: string;
        disabledActionIconColor: string;
        hoverActionIconColor: string;
        focusActionIconColor: string;
        activeActionIconColor: string;
        actionBackgroundColor: string;
        disabledActionBackgroundColor: string;
        hoverActionBackgroundColor: string;
        focusActionBorderColor: string;
        activeActionBackgroundColor: string;
        listDialogBackgroundColor: string;
        listDialogBorderColor: string;
        listOptionDividerColor: string;
        listOptionFontColor: string;
        listOptionFontSize: string;
        listOptionFontStyle: string;
        listOptionFontWeight: string;
        systemMessageFontColor: string;
        errorListDialogFontColor: string;
        errorListDialogBackgroundColor: string;
        errorListDialogBorderColor: string;
        hoverListOptionBackgroundColor: string;
        activeListOptionBackgroundColor: string;
        focusListOptionBorderColor: string;
    };
    toggleGroup: {
        containerBackgroundColor: string;
        containerBorderColor: string;
        labelFontColor: string;
        disabledLabelFontColor: string;
        helperTextFontColor: string;
        disabledHelperTextFontColor: string;
        unselectedBackgroundColor: string;
        unselectedHoverBackgroundColor: string;
        unselectedActiveBackgroundColor: string;
        unselectedDisabledBackgroundColor: string;
        unselectedFontColor: string;
        unselectedDisabledFontColor: string;
        selectedBackgroundColor: string;
        selectedHoverBackgroundColor: string;
        selectedActiveBackgroundColor: string;
        selectedDisabledBackgroundColor: string;
        selectedFontColor: string;
        selectedDisabledFontColor: string;
        focusColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        helperTextFontFamily: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        optionLabelFontFamily: string;
        optionLabelFontSize: string;
        optionLabelFontStyle: string;
        optionLabelFontWeight: string;
        iconPaddingRight: string;
        iconPaddingLeft: string;
        labelPaddingLeft: string;
        labelPaddingRight: string;
        iconMarginRight: string;
        containerMarginTop: string;
        optionBorderThickness: string;
        optionBorderStyle: string;
        optionBorderRadius: string;
        containerBorderThickness: string;
        containerBorderStyle: string;
        containerBorderRadius: string;
        optionFocusBorderThickness: string;
    };
    wizard: {
        visitedStepFontColor: string;
        visitedStepBackgroundColor: string;
        visitedStepBorderColor: string;
        unvisitedStepFontColor: string;
        unvisitedLabelFontColor: string;
        unvisitedHelperTextFontColor: string;
        unvisitedStepBackgroundColor: string;
        unvisitedStepBorderColor: string;
        selectedStepFontColor: string;
        selectedStepBackgroundColor: string;
        selectedStepBorderColor: string;
        selectedLabelFontColor: string;
        selectedHelperTextFontColor: string;
        selectedStepWidth: string;
        selectedStepHeight: string;
        selectedStepBorderThickness: string;
        selectedStepBorderStyle: string;
        selectedStepBorderRadius: string;
        stepFontSize: string;
        stepFontFamily: string;
        stepFontStyle: string;
        stepFontWeight: string;
        stepFontTracking: string;
        stepIconSize: string;
        stepWidth: string;
        stepHeight: string;
        stepBorderThickness: string;
        stepBorderStyle: string;
        stepBorderRadius: string;
        visitedLabelFontColor: string;
        labelFontSize: string;
        labelFontFamily: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelFontTracking: string;
        labelFontTextTransform: string;
        labelTextAlign: string;
        helperTextFontSize: string;
        helperTextFontFamily: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextFontTracking: string;
        helperTextFontTextTransform: string;
        visitedHelperTextFontColor: string;
        helperTextTextAlign: string;
        disabledStepBackgroundColor: string;
        disabledStepFontColor: string;
        disabledLabelFontColor: string;
        disabledHelperTextFontColor: string;
        disabledStepBorderColor: string;
        disabledStepWidth: string;
        disabledStepHeight: string;
        disabledStepBorderThickness: string;
        disabledStepBorderStyle: string;
        disabledStepBorderRadius: string;
        separatorBorderThickness: string;
        separatorBorderStyle: string;
        separatorColor: string;
        focusColor: string;
    };
};
type AdvancedTheme = typeof componentTokens;
type OpinionatedTheme = {
    accordion: {
        accentColor: string;
        titleFontColor: string;
        subLabelFontColor: string;
        assistiveTextFontColor: string;
    };
    alert: {
        baseColor: string;
        accentColor: string;
        overlayColor: string;
    };
    button: {
        baseColor: string;
        primaryFontColor: string;
        secondaryHoverFontColor: string;
    };
    checkbox: {
        baseColor: string;
        checkColor: string;
        fontColor: string;
    };
    chip: {
        baseColor: string;
        fontColor: string;
        iconColor: string;
    };
    contextualMenu: {
        accentColor: string;
        baseColor: string;
        fontColor: string;
        iconColor: string;
    };
    dataGrid: {
        baseColor: string;
        headerFontColor: string;
        cellFontColor: string;
    };
    dateInput: {
        baseColor: string;
        selectedFontColor: string;
    };
    dialog: {
        baseColor: string;
        closeIconColor: string;
        overlayColor: string;
    };
    dropdown: {
        baseColor: string;
        fontColor: string;
        optionFontColor: string;
    };
    fileInput: {
        fontColor: string;
    };
    footer: {
        baseColor: string;
        fontColor: string;
        accentColor: string;
        logo: string;
    };
    header: {
        baseColor: string;
        accentColor: string;
        fontColor: string;
        menuBaseColor: string;
        hamburgerColor: string;
        logo: string;
        logoResponsive: string;
        contentColor: string;
        overlayColor: string;
    };
    link: {
        baseColor: string;
    };
    navTabs: {
        baseColor: string;
        accentColor: string;
    };
    paginator: {
        baseColor: string;
        fontColor: string;
    };
    progressBar: {
        accentColor: string;
        baseColor: string;
        fontColor: string;
        overlayColor: string;
        overlayFontColor: string;
    };
    quickNav: {
        fontColor: string;
        accentColor: string;
    };
    radioGroup: {
        baseColor: string;
        fontColor: string;
    };
    select: {
        selectedOptionBackgroundColor: string;
        fontColor: string;
        optionFontColor: string;
        hoverBorderColor: string;
    };
    sidenav: {
        baseColor: string;
    };
    slider: {
        baseColor: string;
        fontColor: string;
        totalLineColor: string;
    };
    spinner: {
        accentColor: string;
        baseColor: string;
        fontColor: string;
        overlayColor: string;
        overlayFontColor: string;
    };
    switch: {
        checkedBaseColor: string;
        fontColor: string;
    };
    table: {
        baseColor: string;
        headerFontColor: string;
        cellFontColor: string;
    };
    tabs: {
        baseColor: string;
    };
    tag: {
        fontColor: string;
        iconColor: string;
    };
    textarea: {
        fontColor: string;
        hoverBorderColor: string;
    };
    textInput: {
        fontColor: string;
        hoverBorderColor: string;
    };
    toggleGroup: {
        selectedBaseColor: string;
        selectedFontColor: string;
        unselectedBaseColor: string;
        unselectedFontColor: string;
    };
    wizard: {
        baseColor: string;
        fontColor: string;
        selectedStepFontColor: string;
    };
};
declare const defaultTranslatedComponentLabels: {
    applicationLayout: {
        visibilityToggleTitle: string;
    };
    alert: {
        previousMessageActionTitle: string;
        nextMessageActionTitle: string;
        closeAlertActionTitle: string;
        closeMessageActionTitle: string;
    };
    calendar: {
        daysShort: string[];
        months: string[];
        previousMonthTitle: string;
        nextMonthTitle: string;
    };
    dateInput: {
        invalidDateErrorMessage: string;
    };
    dialog: {
        closeIconAriaLabel: string;
    };
    fileInput: {
        fileSizeGreaterThanErrorMessage: string;
        fileSizeLessThanErrorMessage: string;
        multipleButtonLabelDefault: string;
        singleButtonLabelDefault: string;
        dropAreaButtonLabelDefault: string;
        multipleDropAreaLabelDefault: string;
        singleDropAreaLabelDefault: string;
        deleteFileActionTitle: string;
    };
    footer: {
        copyrightText: (year: number) => string;
    };
    formFields: {
        optionalLabel: string;
        requiredSelectionErrorMessage: string;
        requiredValueErrorMessage: string;
        formatRequestedErrorMessage: string;
        lengthErrorMessage: (minLength?: number, maxLength?: number) => string;
        logoAlternativeText: string;
    };
    header: {
        closeIcon: string;
        hamburgerTitle: string;
    };
    numberInput: {
        valueGreaterThanOrEqualToErrorMessage: (value: number) => string;
        valueLessThanOrEqualToErrorMessage: (value: number) => string;
        decrementValueTitle: string;
        incrementValueTitle: string;
    };
    paginator: {
        itemsPerPageText: string;
        minToMaxOfText: (minNumberOfItems: number, maxNumberOfItems: number, totalItems: number) => string;
        goToPageText: string;
        pageOfText: (pageNumber: number, totalPagesNumber: number) => string;
    };
    passwordInput: {
        inputShowPasswordTitle: string;
        inputHidePasswordTitle: string;
    };
    quickNav: {
        contentTitle: string;
    };
    radioGroup: {
        optionalItemLabelDefault: string;
    };
    select: {
        noMatchesErrorMessage: string;
        actionClearSelectionTitle: string;
        actionClearSearchTitle: string;
    };
    tabs: {
        scrollLeft: string;
        scrollRight: string;
    };
    textInput: {
        clearFieldActionTitle: string;
        searchingMessage: string;
        fetchingDataErrorMessage: string;
    };
    toast: {
        clearToastActionTitle: string;
    };
};
type TranslatedLabels = typeof defaultTranslatedComponentLabels;

/**
 * This type is used to allow partial themes and labels objects to be passed to the HalstackProvider.
 * This is an extension of the already existing Partial type, which only allows one level of partiality.
 */
type DeepPartial<T> = {
    [P in keyof T]?: Partial<T[P]>;
};
declare const HalstackContext: react.Context<{
    accordion: {
        backgroundColor: string;
        hoverBackgroundColor: string;
        focusBackgroundColor: string;
        activeBackgroundColor: string;
        arrowColor: string;
        disabledArrowColor: string;
        subLabelFontFamily: string;
        subLabelFontSize: string;
        subLabelFontWeight: string;
        subLabelFontStyle: string;
        subLabelFontColor: string;
        disabledSubLabelFontColor: string;
        assistiveTextFontFamily: string;
        assistiveTextFontSize: string;
        assistiveTextFontWeight: string;
        assistiveTextFontStyle: string;
        assistiveTextFontColor: string;
        disabledAssistiveTextFontColor: string;
        titleLabelFontFamily: string;
        titleLabelFontSize: string;
        titleLabelFontWeight: string;
        titleLabelFontStyle: string;
        titleLabelFontColor: string;
        disabledTitleLabelFontColor: string;
        focusBorderColor: string;
        focusBorderStyle: string;
        focusBorderThickness: string;
        borderRadius: string;
        boxShadowOffsetX: string;
        boxShadowOffsetY: string;
        boxShadowBlur: string;
        boxShadowSpread: string;
        boxShadowColor: string;
        iconColor: string;
        disabledIconColor: string;
        iconSize: string;
        accordionSeparatorBorderColor: string;
        accordionSeparatorBorderThickness: string;
        accordionSeparatorBorderStyle: string;
    };
    alert: {
        errorBackgroundColor: string;
        errorIconColor: string;
        fontColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        iconSize: string;
        infoBackgroundColor: string;
        infoIconColor: string;
        modalBackgroundColor: string;
        modalTitleFontSize: string;
        modalTitleFontWeight: string;
        overlayColor: string;
        successBackgroundColor: string;
        successIconColor: string;
        warningBackgroundColor: string;
        warningIconColor: string;
    };
    bulletedList: {
        fontColor: string;
        bulletIconHeight: string;
        bulletIconWidth: string;
        bulletHeight: string;
        bulletWidth: string;
        bulletMarginRight: string;
    };
    button: {
        labelFontLineHeight: string;
        labelLetterSpacing: string;
        paddingSmallTop: string;
        paddingSmallLeft: string;
        paddingSmallBottom: string;
        paddingSmallRight: string;
        paddingSmallOnlyIconTop: string;
        paddingSmallOnlyIconLeft: string;
        paddingSmallOnlyIconBottom: string;
        paddingSmallOnlyIconRight: string;
        paddingMediumTop: string;
        paddingMediumLeft: string;
        paddingMediumBottom: string;
        paddingMediumRight: string;
        paddingMediumOnlyIconTop: string;
        paddingMediumOnlyIconLeft: string;
        paddingMediumOnlyIconBottom: string;
        paddingMediumOnlyIconRight: string;
        paddingLargeTop: string;
        paddingLargeLeft: string;
        paddingLargeBottom: string;
        paddingLargeRight: string;
        paddingLargeOnlyIconTop: string;
        paddingLargeOnlyIconLeft: string;
        paddingLargeOnlyIconBottom: string;
        paddingLargeOnlyIconRight: string;
        focusBorderColor: string;
        primaryDefaultBackgroundColor: string;
        primaryErrorBackgroundColor: string;
        primaryWarningBackgroundColor: string;
        primarySuccessBackgroundColor: string;
        primaryInfoBackgroundColor: string;
        primaryDefaultFontColor: string;
        primaryErrorFontColor: string;
        primaryWarningFontColor: string;
        primarySuccessFontColor: string;
        primaryInfoFontColor: string;
        primaryHoverDefaultBackgroundColor: string;
        primaryHoverErrorBackgroundColor: string;
        primaryHoverWarningBackgroundColor: string;
        primaryHoverSuccessBackgroundColor: string;
        primaryHoverInfoBackgroundColor: string;
        primaryActiveDefaultBackgroundColor: string;
        primaryActiveErrorBackgroundColor: string;
        primaryActiveWarningBackgroundColor: string;
        primaryActiveSuccessBackgroundColor: string;
        primaryActiveInfoBackgroundColor: string;
        primaryDisabledDefaultBackgroundColor: string;
        primaryDisabledErrorBackgroundColor: string;
        primaryDisabledWarningBackgroundColor: string;
        primaryDisabledSuccessBackgroundColor: string;
        primaryDisabledInfoBackgroundColor: string;
        primaryDisabledDefaultFontColor: string;
        primaryDisabledErrorFontColor: string;
        primaryDisabledWarningFontColor: string;
        primaryDisabledSuccessFontColor: string;
        primaryDisabledInfoFontColor: string;
        primaryBorderThickness: string;
        primaryBorderStyle: string;
        primaryBorderRadius: string;
        primaryFontFamily: string;
        primarySmallFontSize: string;
        primaryMediumFontSize: string;
        primaryLargeFontSize: string;
        primaryFontWeight: string;
        secondaryDefaultBackgroundColor: string;
        secondaryErrorBackgroundColor: string;
        secondaryWarningBackgroundColor: string;
        secondarySuccessBackgroundColor: string;
        secondaryInfoBackgroundColor: string;
        secondaryDefaultFontColor: string;
        secondaryErrorFontColor: string;
        secondaryWarningFontColor: string;
        secondarySuccessFontColor: string;
        secondaryInfoFontColor: string;
        secondaryDefaultBorderColor: string;
        secondaryErrorBorderColor: string;
        secondaryWarningBorderColor: string;
        secondarySuccessBorderColor: string;
        secondaryInfoBorderColor: string;
        secondaryHoverDefaultBackgroundColor: string;
        secondaryHoverErrorBackgroundColor: string;
        secondaryHoverWarningBackgroundColor: string;
        secondaryHoverSuccessBackgroundColor: string;
        secondaryHoverInfoBackgroundColor: string;
        secondaryHoverDefaultFontColor: string;
        secondaryHoverErrorFontColor: string;
        secondaryHoverWarningFontColor: string;
        secondaryHoverSuccessFontColor: string;
        secondaryHoverInfoFontColor: string;
        secondaryActiveDefaultBackgroundColor: string;
        secondaryActiveErrorBackgroundColor: string;
        secondaryActiveWarningBackgroundColor: string;
        secondaryActiveSuccessBackgroundColor: string;
        secondaryActiveInfoBackgroundColor: string;
        secondaryDisabledDefaultBackgroundColor: string;
        secondaryDisabledErrorBackgroundColor: string;
        secondaryDisabledWarningBackgroundColor: string;
        secondaryDisabledSuccessBackgroundColor: string;
        secondaryDisabledInfoBackgroundColor: string;
        secondaryDisabledDefaultFontColor: string;
        secondaryDisabledErrorFontColor: string;
        secondaryDisabledWarningFontColor: string;
        secondaryDisabledSuccessFontColor: string;
        secondaryDisabledInfoFontColor: string;
        secondaryDisabledDefaultBorderColor: string;
        secondaryDisabledErrorBorderColor: string;
        secondaryDisabledWarningBorderColor: string;
        secondaryDisabledSuccessBorderColor: string;
        secondaryDisabledInfoBorderColor: string;
        secondaryBorderThickness: string;
        secondaryBorderStyle: string;
        secondaryBorderRadius: string;
        secondaryFontFamily: string;
        secondarySmallFontSize: string;
        secondaryMediumFontSize: string;
        secondaryLargeFontSize: string;
        secondaryFontWeight: string;
        tertiaryDefaultBackgroundColor: string;
        tertiaryErrorBackgroundColor: string;
        tertiaryWarningBackgroundColor: string;
        tertiarySuccessBackgroundColor: string;
        tertiaryInfoBackgroundColor: string;
        tertiaryDefaultFontColor: string;
        tertiaryErrorFontColor: string;
        tertiaryWarningFontColor: string;
        tertiarySuccessFontColor: string;
        tertiaryInfoFontColor: string;
        tertiaryHoverDefaultBackgroundColor: string;
        tertiaryHoverErrorBackgroundColor: string;
        tertiaryHoverWarningBackgroundColor: string;
        tertiaryHoverSuccessBackgroundColor: string;
        tertiaryHoverInfoBackgroundColor: string;
        tertiaryActiveDefaultBackgroundColor: string;
        tertiaryActiveErrorBackgroundColor: string;
        tertiaryActiveWarningBackgroundColor: string;
        tertiaryActiveSuccessBackgroundColor: string;
        tertiaryActiveInfoBackgroundColor: string;
        tertiaryDisabledDefaultBackgroundColor: string;
        tertiaryDisabledErrorBackgroundColor: string;
        tertiaryDisabledWarningBackgroundColor: string;
        tertiaryDisabledSuccessBackgroundColor: string;
        tertiaryDisabledInfoBackgroundColor: string;
        tertiaryDisabledDefaultFontColor: string;
        tertiaryDisabledErrorFontColor: string;
        tertiaryDisabledWarningFontColor: string;
        tertiaryDisabledSuccessFontColor: string;
        tertiaryDisabledInfoFontColor: string;
        tertiaryBorderThickness: string;
        tertiaryBorderStyle: string;
        tertiaryBorderRadius: string;
        tertiaryFontFamily: string;
        tertiarySmallFontSize: string;
        tertiaryMediumFontSize: string;
        tertiaryLargeFontSize: string;
        tertiaryFontWeight: string;
    };
    card: {
        height: string;
        width: string;
    };
    checkbox: {
        backgroundColorChecked: string;
        hoverBackgroundColorChecked: string;
        disabledBackgroundColorChecked: string;
        readOnlyBackgroundColorChecked: string;
        hoverReadOnlyBackgroundColorChecked: string;
        borderColor: string;
        hoverBorderColor: string;
        disabledBorderColor: string;
        readOnlyBorderColor: string;
        hoverReadOnlyBorderColor: string;
        checkColor: string;
        disabledCheckColor: string;
        readOnlyCheckColor: string;
        fontFamily: string;
        fontSize: string;
        fontWeight: string;
        fontColor: string;
        disabledFontColor: string;
        focusColor: string;
        checkLabelSpacing: string;
    };
    chip: {
        backgroundColor: string;
        disabledBackgroundColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        fontColor: string;
        disabledFontColor: string;
        borderColor: string;
        borderRadius: string;
        borderThickness: string;
        borderStyle: string;
        contentPaddingLeft: string;
        contentPaddingRight: string;
        contentPaddingTop: string;
        contentPaddingBottom: string;
        iconSize: string;
        iconSpacing: string;
        iconColor: string;
        hoverIconColor: string;
        activeIconColor: string;
        disabledIconColor: string;
        focusColor: string;
        focusBorderStyle: string;
        focusBorderThickness: string;
        focusBorderRadius: string;
    };
    contextualMenu: {
        fontFamily: string;
        backgroundColor: string;
        borderColor: string;
        menuItemFontColor: string;
        menuItemFontSize: string;
        menuItemFontStyle: string;
        menuItemFontWeight: string;
        menuItemLineHeight: string;
        hoverMenuItemBackgroundColor: string;
        activeMenuItemBackgroundColor: string;
        selectedMenuItemBackgroundColor: string;
        hoverSelectedMenuItemBackgroundColor: string;
        activeSelectedMenuItemBackgroundColor: string;
        selectedMenuItemFontWeight: string;
        sectionTitleFontColor: string;
        sectionTitleFontSize: string;
        sectionTitleFontStyle: string;
        sectionTitleFontWeight: string;
        sectionTitleLineHeight: string;
        iconColor: string;
        iconSize: string;
    };
    dataGrid: {
        rowSeparatorThickness: string;
        rowSeparatorStyle: string;
        rowSeparatorColor: string;
        dataBackgroundColor: string;
        dataFontFamily: string;
        dataFontSize: string;
        dataFontStyle: string;
        dataFontWeight: string;
        dataFontColor: string;
        dataFontTextTransform: string;
        dataPaddingRight: string;
        dataPaddingLeft: string;
        dataRowHeight: number;
        dataTextLineHeight: string;
        headerBackgroundColor: string;
        headerBorderRadius: string;
        headerFontFamily: string;
        headerFontSize: string;
        headerFontStyle: string;
        headerFontWeight: string;
        headerFontColor: string;
        headerFontTextTransform: string;
        headerPaddingRight: string;
        headerPaddingLeft: string;
        headerRowHeight: number;
        headerTextLineHeight: string;
        headerCheckboxBackgroundColorChecked: string;
        headerCheckboxHoverBackgroundColorChecked: string;
        headerCheckboxBorderColor: string;
        headerCheckboxHoverBorderColor: string;
        headerCheckboxCheckColor: string;
        summaryRowHeight: number;
        focusColor: string;
        scrollBarThumbColor: string;
        scrollBarTrackColor: string;
        actionIconColor: string;
        disabledActionIconColor: string;
        hoverActionIconColor: string;
        focusActionIconColor: string;
        activeActionIconColor: string;
        actionBackgroundColor: string;
        disabledActionBackgroundColor: string;
        hoverActionBackgroundColor: string;
        focusActionBorderColor: string;
        activeActionBackgroundColor: string;
    };
    dateInput: {
        pickerBackgroundColor: string;
        pickerFontColor: string;
        pickerBorderColor: string;
        pickerSelectedBackgroundColor: string;
        pickerSelectedFontColor: string;
        pickerHoverBackgroundColor: string;
        pickerHoverFontColor: string;
        pickerActiveBackgroundColor: string;
        pickerActiveFontColor: string;
        pickerNonCurrentMonthFontColor: string;
        pickerCurrentDateBorderColor: string;
        pickerCurrentDateFontColor: string;
        pickerCurrentYearFontColor: string;
        pickerHeaderBackgroundColor: string;
        pickerHeaderFontColor: string;
        pickerHeaderHoverBackgroundColor: string;
        pickerHeaderHoverFontColor: string;
        pickerHeaderActiveBackgroundColor: string;
        pickerHeaderActiveFontColor: string;
        pickerFocusColor: string;
        pickerBorderWidth: string;
        pickerBorderStyle: string;
        pickerFocusWidth: string;
        pickerCurrentDateBorderWidth: string;
        pickerFontFamily: string;
        pickerFontSize: string;
        pickerFontWeight: string;
        pickerInteractedYearFontSize: string;
        pickerHeaderFontSize: string;
    };
    dialog: {
        overlayColor: string;
        backgroundColor: string;
        closeIconBackgroundColor: string;
        closeIconColor: string;
        boxShadowOffsetX: string;
        boxShadowOffsetY: string;
        boxShadowBlur: string;
        boxShadowColor: string;
    };
    dropdown: {
        buttonBackgroundColor: string;
        hoverButtonBackgroundColor: string;
        activeButtonBackgroundColor: string;
        buttonFontFamily: string;
        buttonFontSize: string;
        buttonFontStyle: string;
        buttonFontWeight: string;
        buttonFontColor: string;
        buttonIconSize: string;
        buttonIconSpacing: string;
        buttonIconColor: string;
        buttonPaddingTop: string;
        buttonPaddingBottom: string;
        buttonPaddingLeft: string;
        buttonPaddingRight: string;
        buttonHeight: string;
        buttonBorderRadius: string;
        buttonBorderStyle: string;
        buttonBorderThickness: string;
        buttonBorderColor: string;
        disabledColor: string;
        disabledButtonBackgroundColor: string;
        disabledButtonBorderColor: string;
        optionBackgroundColor: string;
        hoverOptionBackgroundColor: string;
        activeOptionBackgroundColor: string;
        optionFontFamily: string;
        optionFontSize: string;
        optionFontStyle: string;
        optionFontWeight: string;
        optionFontColor: string;
        optionIconSize: string;
        optionIconSpacing: string;
        optionIconColor: string;
        optionPaddingTop: string;
        optionPaddingBottom: string;
        optionPaddingLeft: string;
        optionPaddingRight: string;
        caretIconSize: string;
        caretIconColor: string;
        caretIconSpacing: string;
        borderRadius: string;
        borderStyle: string;
        borderThickness: string;
        borderColor: string;
        scrollBarThumbColor: string;
        scrollBarTrackColor: string;
        focusColor: string;
    };
    fileInput: {
        dropBorderColor: string;
        fileItemBorderColor: string;
        fileNameFontColor: string;
        labelFontColor: string;
        helperTextFontColor: string;
        dropLabelFontColor: string;
        disabledLabelFontColor: string;
        disabledHelperTextFontColor: string;
        disabledDropLabelFontColor: string;
        focusDropBorderColor: string;
        disabledDropBorderColor: string;
        dragoverDropBackgroundColor: string;
        errorFileItemBorderColor: string;
        errorFileItemBackgroundColor: string;
        errorFilePreviewBackgroundColor: string;
        errorFileItemIconColor: string;
        fileItemIconBackgroundColor: string;
        deleteFileItemColor: string;
        errorMessageFontColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontWeight: string;
        labelLineHeight: string;
        fileItemFontFamily: string;
        fileItemFontSize: string;
        fileItemFontWeight: string;
        fileItemLineHeight: string;
        helperTextFontFamily: string;
        helperTextFontSize: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        dropLabelFontFamily: string;
        dropLabelFontSize: string;
        dropLabelFontWeight: string;
        errorMessageFontFamily: string;
        errorMessageFontSize: string;
        errorMessageFontWeight: string;
        errorMessageLineHeight: string;
        dropBorderThickness: string;
        dropBorderStyle: string;
        dropBorderRadius: string;
        fileItemBorderThickness: string;
        fileItemBorderStyle: string;
        fileItemBorderRadius: string;
        hoverDeleteFileItemBackgroundColor: string;
        activeDeleteFileItemBackgroundColor: string;
        focusDeleteFileItemBorderColor: string;
        filePreviewBackgroundColor: string;
        filePreviewIconColor: string;
        errorFilePreviewIconColor: string;
    };
    footer: {
        height: string;
        backgroundColor: string;
        bottomLinksDividerColor: string;
        bottomLinksDividerThickness: string;
        bottomLinksDividerStyle: string;
        bottomLinksDividerSpacing: string;
        bottomLinksFontFamily: string;
        bottomLinksFontSize: string;
        bottomLinksFontStyle: string;
        bottomLinksFontWeight: string;
        bottomLinksFontColor: string;
        bottomLinksTextDecoration: string;
        copyrightFontFamily: string;
        copyrightFontSize: string;
        copyrightFontStyle: string;
        copyrightFontWeight: string;
        copyrightFontColor: string;
        logo: string;
        logoHeight: string;
        logoWidth: string;
        socialLinksSize: string;
        socialLinksGutter: string;
        socialLinksColor: string;
    };
    header: {
        backgroundColor: string;
        hamburgerFocusColor: string;
        hamburgerFontFamily: string;
        hamburgerFontStyle: string;
        hamburgerFontColor: string;
        hamburgerFontSize: string;
        hamburgerFontWeight: string;
        hamburgerTextTransform: string;
        hamburgerIconColor: string;
        hamburgerHoverColor: string;
        logo: string;
        logoResponsive: string;
        logoHeight: string;
        logoWidth: string;
        menuBackgroundColor: string;
        menuZindex: string;
        menuTabletWidth: string;
        menuMobileWidth: string;
        minHeight: string;
        overlayColor: string;
        overlayOpacity: string;
        overlayZindex: string;
        paddingTop: string;
        paddingBottom: string;
        paddingRight: string;
        paddingLeft: string;
        underlinedColor: string;
        underlinedThickness: string;
        underlinedStyle: string;
        contentColor: string;
    };
    heading: {
        level1FontColor: string;
        level1FontFamily: string;
        level1FontSize: string;
        level1FontStyle: string;
        level1FontWeight: string;
        level1LineHeight: string;
        level1LetterSpacing: string;
        level2FontColor: string;
        level2FontFamily: string;
        level2FontSize: string;
        level2FontStyle: string;
        level2FontWeight: string;
        level2LineHeight: string;
        level2LetterSpacing: string;
        level3FontColor: string;
        level3FontFamily: string;
        level3FontSize: string;
        level3FontStyle: string;
        level3FontWeight: string;
        level3LineHeight: string;
        level3LetterSpacing: string;
        level4FontColor: string;
        level4FontFamily: string;
        level4FontSize: string;
        level4FontStyle: string;
        level4FontWeight: string;
        level4LineHeight: string;
        level4LetterSpacing: string;
        level5FontColor: string;
        level5FontFamily: string;
        level5FontSize: string;
        level5FontStyle: string;
        level5FontWeight: string;
        level5LineHeight: string;
        level5LetterSpacing: string;
    };
    image: {
        captionFontColor: string;
        captionFontFamily: string;
        captionFontSize: string;
        captionFontStyle: string;
        captionFontWeight: string;
        captionLineHeight: string;
    };
    link: {
        fontColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        iconSize: string;
        iconSpacing: string;
        underlineSpacing: string;
        underlineStyle: string;
        underlineThickness: string;
        disabledFontColor: string;
        hoverFontColor: string;
        hoverUnderlineColor: string;
        visitedFontColor: string;
        visitedUnderlineColor: string;
        activeFontColor: string;
        activeUnderlineColor: string;
        focusColor: string;
    };
    navTabs: {
        selectedBackgroundColor: string;
        unselectedBackgroundColor: string;
        hoverBackgroundColor: string;
        pressedBackgroundColor: string;
        selectedFontColor: string;
        unselectedFontColor: string;
        disabledFontColor: string;
        focusOutline: string;
        selectedUnderlineColor: string;
        dividerColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        selectedIconColor: string;
        unselectedIconColor: string;
        disabledIconColor: string;
    };
    paginator: {
        backgroundColor: string;
        fontColor: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        fontTextTransform: string;
        verticalPadding: string;
        horizontalPadding: string;
        marginRight: string;
        marginLeft: string;
        itemsPerPageSelectorMarginLeft: string;
        itemsPerPageSelectorMarginRight: string;
        pageSelectorMarginRight: string;
        pageSelectorMarginLeft: string;
        totalItemsContainerMarginRight: string;
        totalItemsContainerMarginLeft: string;
    };
    paragraph: {
        display: string;
        fontColor: string;
        fontSize: string;
        fontWeight: string;
    };
    progressBar: {
        trackLineColor: string;
        totalLineColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelFontColor: string;
        labelFontTextTransform: string;
        valueFontFamily: string;
        valueFontSize: string;
        valueFontStyle: string;
        valueFontWeight: string;
        valueFontColor: string;
        valueFontTextTransform: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextFontFamily: string;
        thickness: string;
        borderRadius: string;
        overlayColor: string;
        overlayFontColor: string;
    };
    quickNav: {
        fontColor: string;
        hoverFontColor: string;
        dividerBorderColor: string;
        focusBorderColor: string;
        focusBorderStyle: string;
        focusBorderThickness: string;
        focusBorderRadius: string;
        paddingTop: string;
        paddingBottom: string;
        paddingLeft: string;
        paddingRight: string;
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
    };
    radioGroup: {
        fontFamily: string;
        radioInputColor: string;
        hoverRadioInputColor: string;
        focusBorderColor: string;
        activeRadioInputColor: string;
        errorRadioInputColor: string;
        hoverErrorRadioInputColor: string;
        activeErrorRadioInputColor: string;
        readOnlyRadioInputColor: string;
        hoverReadOnlyRadioInputColor: string;
        activeReadOnlyRadioInputColor: string;
        disabledRadioInputColor: string;
        disabledLabelFontColor: string;
        disabledHelperTextFontColor: string;
        disabledRadioInputLabelFontColor: string;
        errorMessageColor: string;
        labelFontColor: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        optionalLabelFontWeight: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        radioInputLabelFontColor: string;
        radioInputLabelFontSize: string;
        radioInputLabelFontStyle: string;
        radioInputLabelFontWeight: string;
        radioInputLabelLineHeight: string;
        groupLabelMargin: string;
        radioInputLabelMargin: string;
        groupVerticalGutter: string;
        groupHorizontalGutter: string;
    };
    select: {
        fontFamily: string;
        disabledColor: string;
        enabledInputBorderColor: string;
        hoverInputBorderColor: string;
        focusInputBorderColor: string;
        errorInputBorderColor: string;
        hoverInputErrorBorderColor: string;
        disabledInputBorderColor: string;
        disabledInputBackgroundColor: string;
        inputMarginTop: string;
        inputMarginBottom: string;
        errorMessageColor: string;
        errorIconColor: string;
        labelFontColor: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        optionalLabelFontWeight: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        placeholderFontColor: string;
        valueFontColor: string;
        valueFontSize: string;
        valueFontStyle: string;
        valueFontWeight: string;
        actionIconColor: string;
        hoverActionIconColor: string;
        activeActionIconColor: string;
        actionBackgroundColor: string;
        hoverActionBackgroundColor: string;
        activeActionBackgroundColor: string;
        listOptionFontColor: string;
        listOptionFontSize: string;
        listOptionFontStyle: string;
        listOptionFontWeight: string;
        listOptionIconColor: string;
        listOptionDividerColor: string;
        listGroupLabelFontWeight: string;
        focusListOptionBorderColor: string;
        systemMessageFontColor: string;
        collapseIndicatorColor: string;
        listDialogBackgroundColor: string;
        listDialogBorderColor: string;
        selectedListOptionBackgroundColor: string;
        selectedHoverListOptionBackgroundColor: string;
        selectedActiveListOptionBackgroundColor: string;
        selectedListOptionIconColor: string;
        unselectedHoverListOptionBackgroundColor: string;
        unselectedActiveListOptionBackgroundColor: string;
        selectionIndicatorFontColor: string;
        selectionIndicatorFontSize: string;
        selectionIndicatorFontStyle: string;
        selectionIndicatorFontWeight: string;
        selectionIndicatorBorderColor: string;
        selectionIndicatorBackgroundColor: string;
        enabledSelectionIndicatorActionBackgroundColor: string;
        enabledSelectionIndicatorActionIconColor: string;
        hoverSelectionIndicatorActionBackgroundColor: string;
        hoverSelectionIndicatorActionIconColor: string;
        activeSelectionIndicatorActionBackgroundColor: string;
        activeSelectionIndicatorActionIconColor: string;
    };
    sidenav: {
        backgroundColor: string;
        titleFontFamily: string;
        titleFontSize: string;
        titleFontStyle: string;
        titleFontWeight: string;
        titleFontColor: string;
        titleFontTextTransform: string;
        titleFontLetterSpacing: string;
        groupTitleFontFamily: string;
        groupTitleFontSize: string;
        groupTitleFontStyle: string;
        groupTitleFontWeight: string;
        groupTitleFontColor: string;
        groupTitleHoverBackgroundColor: string;
        groupTitleActiveBackgroundColor: string;
        groupTitleSelectedFontColor: string;
        groupTitleSelectedBackgroundColor: string;
        groupTitleSelectedHoverFontColor: string;
        groupTitleSelectedHoverBackgroundColor: string;
        groupTitleFontTextTransform: string;
        groupTitleFontLetterSpacing: string;
        linkFontFamily: string;
        linkFontSize: string;
        linkFontStyle: string;
        linkFontWeight: string;
        linkFontColor: string;
        linkHoverBackgroundColor: string;
        linkSelectedFontColor: string;
        linkSelectedBackgroundColor: string;
        linkSelectedHoverFontColor: string;
        linkSelectedHoverBackgroundColor: string;
        linkFontTextTransform: string;
        linkFontLetterSpacing: string;
        linkTextDecoration: string;
        linkMarginTop: string;
        linkMarginBottom: string;
        linkMarginRight: string;
        linkMarginLeft: string;
        linkFocusColor: string;
        scrollBarThumbColor: string;
        scrollBarTrackColor: string;
    };
    slider: {
        fontFamily: string;
        limitValuesFontColor: string;
        limitValuesFontSize: string;
        limitValuesFontStyle: string;
        limitValuesFontWeight: string;
        limitValuesFontLetterSpacing: string;
        disabledLimitValuesFontColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        helperTextFontFamily: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        fontColor: string;
        labelFontColor: string;
        helperTextFontColor: string;
        disabledLabelFontColor: string;
        disabledHelperTextFontColor: string;
        thumbHeight: string;
        thumbWidth: string;
        hoverThumbHeight: string;
        hoverThumbWidth: string;
        thumbVerticalPosition: string;
        hoverThumbVerticalPosition: string;
        thumbBackgroundColor: string;
        hoverThumbScale: string;
        hoverThumbBackgroundColor: string;
        activeThumbScale: string;
        activeThumbBackgroundColor: string;
        focusThumbBackgroundColor: string;
        tickHeight: string;
        tickWidth: string;
        tickVerticalPosition: string;
        tickBackgroundColor: string;
        trackLineThickness: string;
        trackLineVerticalPosition: string;
        trackLineColor: string;
        totalLineThickness: string;
        totalLineVerticalPosition: string;
        totalLineColor: string;
        disabledThumbVerticalPosition: string;
        disabledThumbBackgroundColor: string;
        disabledTickVerticalPosition: string;
        disabledTickBackgroundColor: string;
        disabledTrackLineColor: string;
        disabledTotalLineColor: string;
        focusColor: string;
        floorLabelMarginRight: string;
        ceilLabelMarginLeft: string;
        inputMarginLeft: string;
    };
    spinner: {
        trackCircleColor: string;
        trackCircleColorOverlay: string;
        totalCircleColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelFontColor: string;
        labelTextAlign: string;
        progressValueFontFamily: string;
        progressValueFontSize: string;
        progressValueFontStyle: string;
        progressValueFontWeight: string;
        progressValueFontColor: string;
        progressValueTextAlign: string;
        overlayBackgroundColor: string;
        overlayOpacity: string;
        overlayLabelFontFamily: string;
        overlayLabelFontSize: string;
        overlayLabelFontStyle: string;
        overlayLabelFontWeight: string;
        overlayLabelFontColor: string;
        overlayLabelTextAlign: string;
        overlayProgressValueFontFamily: string;
        overlayProgressValueFontSize: string;
        overlayProgressValueFontStyle: string;
        overlayProgressValueFontWeight: string;
        overlayProgressValueFontColor: string;
        overlayProgressValueTextAlign: string;
    };
    switch: {
        checkedTrackBackgroundColor: string;
        checkedThumbBackgroundColor: string;
        uncheckedTrackBackgroundColor: string;
        uncheckedThumbBackgroundColor: string;
        disabledCheckedTrackBackgroundColor: string;
        disabledCheckedThumbBackgroundColor: string;
        disabledUncheckedTrackBackgroundColor: string;
        disabledUncheckedThumbBackgroundColor: string;
        disabledLabelFontColor: string;
        disabledLabelFontStyle: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelFontColor: string;
        thumbFocusColor: string;
        thumbHeight: string;
        thumbWidth: string;
        thumbShift: string;
        trackHeight: string;
        trackWidth: string;
        spaceBetweenLabelSwitch: string;
    };
    table: {
        rowSeparatorThickness: string;
        rowSeparatorStyle: string;
        rowSeparatorColor: string;
        dataBackgroundColor: string;
        dataFontFamily: string;
        dataFontSize: string;
        dataFontStyle: string;
        dataFontWeight: string;
        dataFontColor: string;
        dataFontTextTransform: string;
        dataPaddingTop: string;
        dataPaddingBottom: string;
        dataPaddingRight: string;
        dataPaddingLeft: string;
        dataPaddingTopReduced: string;
        dataPaddingBottomReduced: string;
        dataPaddingRightReduced: string;
        dataPaddingLeftReduced: string;
        dataTextAlign: string;
        dataTextLineHeight: string;
        firstChildPaddingLeft: string;
        lastChildPaddingRight: string;
        firstChildPaddingLeftReduced: string;
        lastChildPaddingRightReduced: string;
        headerBackgroundColor: string;
        headerBorderRadius: string;
        headerFontFamily: string;
        headerFontSize: string;
        headerFontStyle: string;
        headerFontWeight: string;
        headerFontColor: string;
        headerFontTextTransform: string;
        headerPaddingTop: string;
        headerPaddingBottom: string;
        headerPaddingRight: string;
        headerPaddingLeft: string;
        headerPaddingTopReduced: string;
        headerPaddingBottomReduced: string;
        headerPaddingRightReduced: string;
        headerPaddingLeftReduced: string;
        headerTextAlign: string;
        headerTextLineHeight: string;
        scrollBarThumbColor: string;
        scrollBarTrackColor: string;
        sortIconColor: string;
        actionIconColor: string;
        disabledActionIconColor: string;
        hoverActionIconColor: string;
        focusActionIconColor: string;
        activeActionIconColor: string;
        actionBackgroundColor: string;
        disabledActionBackgroundColor: string;
        hoverActionBackgroundColor: string;
        focusActionBorderColor: string;
        activeActionBackgroundColor: string;
    };
    tabs: {
        fontFamily: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        fontTextTransform: string;
        selectedBackgroundColor: string;
        selectedFontColor: string;
        selectedIconColor: string;
        selectedUnderlineColor: string;
        selectedUnderlineThickness: string;
        unselectedBackgroundColor: string;
        unselectedFontColor: string;
        unselectedIconColor: string;
        disabledFontColor: string;
        disabledIconColor: string;
        disabledFontStyle: string;
        hoverBackgroundColor: string;
        pressedBackgroundColor: string;
        pressedFontWeight: string;
        dividerColor: string;
        dividerThickness: string;
        focusOutline: string;
        scrollButtonsWidth: string;
    };
    tag: {
        fontFamily: string;
        fontColor: string;
        fontSize: string;
        fontStyle: string;
        fontWeight: string;
        labelPaddingTop: string;
        labelPaddingBottom: string;
        labelPaddingLeft: string;
        labelPaddingRight: string;
        height: string;
        iconColor: string;
        iconSectionWidth: string;
        iconHeight: string;
        iconWidth: string;
        focusColor: string;
    };
    textarea: {
        fontFamily: string;
        enabledBorderColor: string;
        hoverBorderColor: string;
        focusBorderColor: string;
        disabledBorderColor: string;
        disabledContainerFillColor: string;
        readOnlyBorderColor: string;
        hoverReadOnlyBorderColor: string;
        errorBorderColor: string;
        hoverErrorBorderColor: string;
        inputMarginTop: string;
        inputMarginBottom: string;
        errorMessageColor: string;
        labelFontColor: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        disabledLabelFontColor: string;
        optionalLabelFontWeight: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        disabledHelperTextFontColor: string;
        placeholderFontColor: string;
        disabledPlaceholderFontColor: string;
        valueFontColor: string;
        valueFontSize: string;
        valueFontStyle: string;
        valueFontWeight: string;
        disabledValueFontColor: string;
    };
    textInput: {
        fontFamily: string;
        enabledBorderColor: string;
        hoverBorderColor: string;
        focusBorderColor: string;
        disabledBorderColor: string;
        disabledContainerFillColor: string;
        readOnlyBorderColor: string;
        hoverReadOnlyBorderColor: string;
        errorBorderColor: string;
        hoverErrorBorderColor: string;
        inputMarginTop: string;
        inputMarginBottom: string;
        errorMessageColor: string;
        errorIconColor: string;
        labelFontColor: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        disabledLabelFontColor: string;
        optionalLabelFontWeight: string;
        helperTextFontColor: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        disabledHelperTextFontColor: string;
        prefixColor: string;
        prefixDividerBorderWidth: string;
        prefixDividerBorderStyle: string;
        prefixDividerPaddingRight: string;
        suffixColor: string;
        suffixDividerBorderStyle: string;
        suffixDividerBorderWidth: string;
        suffixDividerPaddingLeft: string;
        disabledPrefixColor: string;
        disabledSuffixColor: string;
        placeholderFontColor: string;
        disabledPlaceholderFontColor: string;
        valueFontColor: string;
        valueFontSize: string;
        valueFontStyle: string;
        valueFontWeight: string;
        disabledValueFontColor: string;
        actionIconColor: string;
        disabledActionIconColor: string;
        hoverActionIconColor: string;
        focusActionIconColor: string;
        activeActionIconColor: string;
        actionBackgroundColor: string;
        disabledActionBackgroundColor: string;
        hoverActionBackgroundColor: string;
        focusActionBorderColor: string;
        activeActionBackgroundColor: string;
        listDialogBackgroundColor: string;
        listDialogBorderColor: string;
        listOptionDividerColor: string;
        listOptionFontColor: string;
        listOptionFontSize: string;
        listOptionFontStyle: string;
        listOptionFontWeight: string;
        systemMessageFontColor: string;
        errorListDialogFontColor: string;
        errorListDialogBackgroundColor: string;
        errorListDialogBorderColor: string;
        hoverListOptionBackgroundColor: string;
        activeListOptionBackgroundColor: string;
        focusListOptionBorderColor: string;
    };
    toggleGroup: {
        containerBackgroundColor: string;
        containerBorderColor: string;
        labelFontColor: string;
        disabledLabelFontColor: string;
        helperTextFontColor: string;
        disabledHelperTextFontColor: string;
        unselectedBackgroundColor: string;
        unselectedHoverBackgroundColor: string;
        unselectedActiveBackgroundColor: string;
        unselectedDisabledBackgroundColor: string;
        unselectedFontColor: string;
        unselectedDisabledFontColor: string;
        selectedBackgroundColor: string;
        selectedHoverBackgroundColor: string;
        selectedActiveBackgroundColor: string;
        selectedDisabledBackgroundColor: string;
        selectedFontColor: string;
        selectedDisabledFontColor: string;
        focusColor: string;
        labelFontFamily: string;
        labelFontSize: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelLineHeight: string;
        helperTextFontFamily: string;
        helperTextFontSize: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextLineHeight: string;
        optionLabelFontFamily: string;
        optionLabelFontSize: string;
        optionLabelFontStyle: string;
        optionLabelFontWeight: string;
        iconPaddingRight: string;
        iconPaddingLeft: string;
        labelPaddingLeft: string;
        labelPaddingRight: string;
        iconMarginRight: string;
        containerMarginTop: string;
        optionBorderThickness: string;
        optionBorderStyle: string;
        optionBorderRadius: string;
        containerBorderThickness: string;
        containerBorderStyle: string;
        containerBorderRadius: string;
        optionFocusBorderThickness: string;
    };
    wizard: {
        visitedStepFontColor: string;
        visitedStepBackgroundColor: string;
        visitedStepBorderColor: string;
        unvisitedStepFontColor: string;
        unvisitedLabelFontColor: string;
        unvisitedHelperTextFontColor: string;
        unvisitedStepBackgroundColor: string;
        unvisitedStepBorderColor: string;
        selectedStepFontColor: string;
        selectedStepBackgroundColor: string;
        selectedStepBorderColor: string;
        selectedLabelFontColor: string;
        selectedHelperTextFontColor: string;
        selectedStepWidth: string;
        selectedStepHeight: string;
        selectedStepBorderThickness: string;
        selectedStepBorderStyle: string;
        selectedStepBorderRadius: string;
        stepFontSize: string;
        stepFontFamily: string;
        stepFontStyle: string;
        stepFontWeight: string;
        stepFontTracking: string;
        stepIconSize: string;
        stepWidth: string;
        stepHeight: string;
        stepBorderThickness: string;
        stepBorderStyle: string;
        stepBorderRadius: string;
        visitedLabelFontColor: string;
        labelFontSize: string;
        labelFontFamily: string;
        labelFontStyle: string;
        labelFontWeight: string;
        labelFontTracking: string;
        labelFontTextTransform: string;
        labelTextAlign: string;
        helperTextFontSize: string;
        helperTextFontFamily: string;
        helperTextFontStyle: string;
        helperTextFontWeight: string;
        helperTextFontTracking: string;
        helperTextFontTextTransform: string;
        visitedHelperTextFontColor: string;
        helperTextTextAlign: string;
        disabledStepBackgroundColor: string;
        disabledStepFontColor: string;
        disabledLabelFontColor: string;
        disabledHelperTextFontColor: string;
        disabledStepBorderColor: string;
        disabledStepWidth: string;
        disabledStepHeight: string;
        disabledStepBorderThickness: string;
        disabledStepBorderStyle: string;
        disabledStepBorderRadius: string;
        separatorBorderThickness: string;
        separatorBorderStyle: string;
        separatorColor: string;
        focusColor: string;
    };
}>;
declare const HalstackLanguageContext: react.Context<{
    applicationLayout: {
        visibilityToggleTitle: string;
    };
    alert: {
        previousMessageActionTitle: string;
        nextMessageActionTitle: string;
        closeAlertActionTitle: string;
        closeMessageActionTitle: string;
    };
    calendar: {
        daysShort: string[];
        months: string[];
        previousMonthTitle: string;
        nextMonthTitle: string;
    };
    dateInput: {
        invalidDateErrorMessage: string;
    };
    dialog: {
        closeIconAriaLabel: string;
    };
    fileInput: {
        fileSizeGreaterThanErrorMessage: string;
        fileSizeLessThanErrorMessage: string;
        multipleButtonLabelDefault: string;
        singleButtonLabelDefault: string;
        dropAreaButtonLabelDefault: string;
        multipleDropAreaLabelDefault: string;
        singleDropAreaLabelDefault: string;
        deleteFileActionTitle: string;
    };
    footer: {
        copyrightText: (year: number) => string;
    };
    formFields: {
        optionalLabel: string;
        requiredSelectionErrorMessage: string;
        requiredValueErrorMessage: string;
        formatRequestedErrorMessage: string;
        lengthErrorMessage: (minLength?: number, maxLength?: number) => string;
        logoAlternativeText: string;
    };
    header: {
        closeIcon: string;
        hamburgerTitle: string;
    };
    numberInput: {
        valueGreaterThanOrEqualToErrorMessage: (value: number) => string;
        valueLessThanOrEqualToErrorMessage: (value: number) => string;
        decrementValueTitle: string;
        incrementValueTitle: string;
    };
    paginator: {
        itemsPerPageText: string;
        minToMaxOfText: (minNumberOfItems: number, maxNumberOfItems: number, totalItems: number) => string;
        goToPageText: string;
        pageOfText: (pageNumber: number, totalPagesNumber: number) => string;
    };
    passwordInput: {
        inputShowPasswordTitle: string;
        inputHidePasswordTitle: string;
    };
    quickNav: {
        contentTitle: string;
    };
    radioGroup: {
        optionalItemLabelDefault: string;
    };
    select: {
        noMatchesErrorMessage: string;
        actionClearSelectionTitle: string;
        actionClearSearchTitle: string;
    };
    tabs: {
        scrollLeft: string;
        scrollRight: string;
    };
    textInput: {
        clearFieldActionTitle: string;
        searchingMessage: string;
        fetchingDataErrorMessage: string;
    };
    toast: {
        clearToastActionTitle: string;
    };
}>;
type HalstackProviderPropsType = {
    theme?: DeepPartial<OpinionatedTheme>;
    advancedTheme?: DeepPartial<AdvancedTheme>;
    labels?: DeepPartial<TranslatedLabels>;
    children: ReactNode;
};
declare const HalstackProvider: ({ theme, advancedTheme, labels, children }: HalstackProviderPropsType) => JSX.Element;

declare const useToast: () => {
    default: (toast: DefaultToast) => (() => void) | undefined;
    success: (toast: SemanticToast) => (() => void) | undefined;
    warning: (toast: SemanticToast) => (() => void) | undefined;
    info: (toast: SemanticToast) => (() => void) | undefined;
    loading: (toast: Omit<LoadingToast, "loading">) => (() => void) | undefined;
};

export { DxcAccordion, DxcAlert, DxcApplicationLayout, DxcBadge, Bleed as DxcBleed, DxcBreadcrumbs, DxcBulletedList, DxcButton, DxcCard, DxcCheckbox, DxcChip, DxcContainer, DxcContextualMenu, DxcDataGrid, DxcDateInput, DxcDialog, DxcDivider, DxcDropdown, DxcFileInput, DxcFlex, DxcGrid, DxcHeading, DxcImage, Inset as DxcInset, DxcLink, DxcNavTabs, DxcNumberInput, DxcPaginator, DxcParagraph, DxcPasswordInput, DxcProgressBar, DxcQuickNav, DxcRadioGroup, DxcResultsetTable, DxcSelect, DxcSlider, DxcSpinner, DxcStatusLight, DxcSwitch, DxcTable, DxcTabs, DxcTag, DxcTextInput, DxcTextarea, DxcToastsQueue, DxcToggleGroup, DxcTooltip, DxcTypography, DxcWizard, HalstackContext, HalstackLanguageContext, HalstackProvider, useToast };
